#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

library(shiny)
library(shinycssloaders)
library(shiny)
#library(clusterProfiler)
library(pathview)
#library(ChIPseeker)
#library(ChIPpeakAnno)
#library(rtracklayer)
#library(seqinr)
library(shinythemes)
library(shinyjs)
## Load microalgae annotation packages
library(org.Otauri.eg.db) 
#install.packages(pkgs = "TxDb.Otauri.JGI/",repos = NULL,type="source")

## Load microalgae genome annotation packages
library(TxDb.Otauri.JGI)

## Auxiliary functions
## Auxiliary function to compute enrichments
compute.enrichments <- function(gene.ratios, bg.ratios)
{
    gene.ratios.eval <- sapply(parse(text=gene.ratios),FUN = eval)
    bg.ratios.eval <- sapply(parse(text=bg.ratios),FUN = eval)
    enrichments <- round(x=gene.ratios.eval/bg.ratios.eval,digits = 2)
    enrichments.text <- paste(enrichments, " (", gene.ratios, "; ", bg.ratios, ")",sep="")
    
    return(enrichments.text)  
}

## Auxiliary function to split a string using commas
split.commas <- function(annotation.str)
{
    return(strsplit(annotation.str,split=",")[[1]])
}

## Ostreococcus tauri gene link to ORCAE
## https://bioinformatics.psb.ugent.be/orcae/annotation/OsttaV2/current/ostta15g02520
ostta.gene.link <- function(gene.name)
{
    orcae.link <- paste0("https://bioinformatics.psb.ugent.be/orcae/annotation/OsttaV2/current/",gene.name)
    gene.link <- paste(c("<a href=\"",
                         orcae.link,
                         "\" target=\"_blank\">",
                         gene.name, "</a>"),
                       collapse="")
    return(gene.link)
}

## Gene Ontology term link
# http://amigo.geneontology.org/amigo/term/GO:0015979
go.link <- function(go.term)
{
    link <- paste0("http://amigo.geneontology.org/amigo/term/", go.term)
    complete.link <- paste(c("<a href=\"",
                             link,
                             "\" target=\"_blank\">",
                             go.term, "</a>"),
                           collapse = "")
    return(complete.link)
}

## KO link
#https://www.genome.jp/dbget-bin/www_bget?ko:K00276
ko.link <- function(ko.term)
{
    link <- paste0("https://www.genome.jp/dbget-bin/www_bget?ko:", ko.term)
    complete.link <- paste(c("<a href=\"",
                             link,
                             "\" target=\"_blank\">",
                             ko.term, "</a>"),
                           collapse = "")
    return(complete.link)
}

## KOG link
## https://www.ncbi.nlm.nih.gov/Structure/cdd/KOG3720
kog.link <- function(kog.term)
{
    link <- paste0("https://www.ncbi.nlm.nih.gov/Structure/cdd/KOG3720", kog.term)
    complete.link <- paste(c("<a href=\"",
                             link,
                             "\" target=\"_blank\">",
                             kog.term, "</a>"),
                           collapse = "")
    return(complete.link)
}

## ENZYME link
## https://www.brenda-enzymes.org/enzyme.php?ecno=1.4.3.21
enzyme.link <- function(ec.term)
{
    link <- paste0("https://www.brenda-enzymes.org/enzyme.php?ecno=", ec.term)
    complete.link <- paste(c("<a href=\"",
                             link,
                             "\" target=\"_blank\">",
                             ec.term, "</a>"),
                           collapse = "")
    return(complete.link)
}

## KEGG pathway link
## https://www.genome.jp/kegg-bin/show_pathway?cre04136
kegg.pathway.link <- function(kegg.pathway)
{
    link <- paste0("https://www.genome.jp/kegg-bin/show_pathway?",kegg.pathway)
    complete.link <- paste(c("<a href=\"",
                             link,
                             "\" target=\"_blank\">",
                             kegg.pathway, "</a>"),
                           collapse = "")
    return(complete.link)
}

## KEGG module link
## https://www.genome.jp/kegg-bin/show_module?cre04136
kegg.module.link <- function(kegg.module)
{
    link <- paste0("https://www.genome.jp/kegg-bin/show_module?",kegg.module)
    complete.link <- paste(c("<a href=\"",
                             link,
                             "\" target=\"_blank\">",
                             kegg.module, "</a>"),
                           collapse = "")
    return(complete.link)
}

####SD plot
plot.sd <- function(gene.id, gene.expression)
{
  sd.zt <- paste("sd",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.sd <- gene.expression[gene.id,c(paste(sd.zt,1,sep="_"),
                                                             paste(sd.zt,2,sep="_"),
                                                             paste(sd.zt,3,sep="_"))]
  
  min.expression <- min(current.gene.expression.sd)
  max.expression <- max(current.gene.expression.sd)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.sd[1,]),type="o",lwd=3,col="red",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
}

plot.sd.prot <- function(gene.id, gene.expression)
{
  
  current.gene.expression.sd <- gene.expression
  
  min.expression <- min(current.gene.expression.sd)
  max.expression <- max(current.gene.expression.sd)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.sd[1,]),type="o",lwd=3,col="red",axes=F,xlab="",ylab="Abundance",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
}

# gene.id <-"ostta05g02426"
# gene.expression <- total.gene.expression
# protein.data <- protein.SD
plot.sd.gene.prot <- function(gene.id, gene.expression, protein.data)
{
  
  sd.zt <- paste("sd",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.sd <- gene.expression[gene.id,c(paste(sd.zt,1,sep="_"),
                                                          paste(sd.zt,2,sep="_"),
                                                          paste(sd.zt,3,sep="_"))]
  current.gene.expression.sd <- current.gene.expression.sd/max(current.gene.expression.sd)
  current.protein.sd <- protein.data/max(protein.data)
  
  
  min.expression <- min(current.gene.expression.sd, current.protein.sd)
  max.expression <- max(current.gene.expression.sd, current.protein.sd)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.protein.sd),type="o",lwd=3,col="salmon",axes=F,xlab="",ylab="Abundance",
       ylim=c(0,max.expression),xlim=c(0,21),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos =-0.1, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  lines(as.numeric(current.gene.expression.sd),type="o",lwd=3,col="red3",
        ylim=c(min.expression-expression.step,max.expression))
  legend("topright", 
         legend = c("protein", "gene"), 
         lwd=2, col = c("salmon", "red"), 
         lty=c(1,1))
  polygon(x = c(1,3,3,1),y=c(-0.01,
                               -0.01,
                               -0.04,
                               -0.04),lwd=2,border="red")
  
  polygon(x = c(3,7,7,3),y=c(-0.01,
                             -0.01,
                             -0.04,
                             -0.04),lwd=2,border="red",col="red")
  
  polygon(x = c(7,9,9,7),y=c(-0.01,
                             -0.01,
                             -0.04,
                             -0.04),lwd=2,border="red")
  
  polygon(x = c(9,13,13,9),y=c(-0.01,
                               -0.01,
                               -0.04,
                               -0.04),lwd=2,border="red",col="red")
  
  polygon(x = c(13,15,15,13),y=c(-0.01,
                                 -0.01,
                                 -0.04,
                                 -0.04),lwd=2,border="red")
  
  polygon(x = c(15,19,19,15),y=c(-0.01,
                                 -0.01,
                                 -0.04,
                                 -0.04),lwd=2,border="red",col="red")
  
}

plot.sd.ll <- function(gene.id, gene.expression)
{
  sd.zt <- paste("sd",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.sd.ll <- gene.expression[gene.id,c(paste(sd.zt,1,sep="_"),
                                                             paste(sd.zt,2,sep="_"),
                                                             paste(sd.zt,3,sep="_"),
                                                             paste(sd.zt,4,sep="_"),
                                                             paste(sd.zt,5,sep="_"))]
  
  min.expression <- min(current.gene.expression.sd.ll)
  max.expression <- max(current.gene.expression.sd.ll)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.sd.ll[1,]),type="o",lwd=3,col="red",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=30),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),5),las=2,lwd=3)
  
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(19,21,21,19),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(21,25,25,21),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  
  polygon(x = c(25,27,27,25),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(27,30,30,27),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  
}

plot.sd.dd <- function(gene.id, gene.expression)
{
  sd.zt <- paste("sd",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.sd.dd <- gene.expression[gene.id,c(paste(sd.zt,1,sep="_"),
                                                             paste(sd.zt,2,sep="_"),
                                                             paste(sd.zt,3,sep="_"),
                                                             paste(sd.zt,6,sep="_"),
                                                             paste(sd.zt,7,sep="_"))]
  
  min.expression <- min(current.gene.expression.sd.dd)
  max.expression <- max(current.gene.expression.sd.dd)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.sd.dd),type="o",lwd=3,col="red",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=30),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),5),las=2,lwd=3)
  
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(19,21,21,19),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  
  polygon(x = c(21,25,25,21),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(25,27,27,25),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  polygon(x = c(27,30,30,27),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
}

####LD plots
plot.ld <- function(gene.id, gene.expression)
{
  ld.zt <- paste("ld",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.ld <- gene.expression[gene.id,c(paste(ld.zt,1,sep="_"),
                                                             paste(ld.zt,2,sep="_"),
                                                             paste(ld.zt,3,sep="_"))]
  
  min.expression <- min(current.gene.expression.ld)
  max.expression <- max(current.gene.expression.ld)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
}

plot.ld.prot <- function(gene.id, gene.expression)
{
  
  current.gene.expression.ld <- gene.expression
  
  min.expression <- min(current.gene.expression.ld)
  max.expression <- max(current.gene.expression.ld)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="Abundance",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
}


plot.ld.gene.prot <- function(gene.id, gene.expression, protein.data)
{
  
  ld.zt <- paste("ld",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.ld <- gene.expression[gene.id,c(paste(ld.zt,1,sep="_"),
                                                          paste(ld.zt,2,sep="_"),
                                                          paste(ld.zt,3,sep="_"))]
  current.gene.expression.ld <- current.gene.expression.ld/max(current.gene.expression.ld)
  current.protein.ld <- protein.data/max(protein.data)
  
  
  min.expression <- min(current.gene.expression.ld, current.protein.ld)
  max.expression <- max(current.gene.expression.ld, current.protein.ld)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.protein.ld),type="o",lwd=3,col="lightblue",axes=F,xlab="",ylab="Abundance",
       ylim=c(0,max.expression),xlim=c(0,21),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = -0.1, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  lines(as.numeric(current.gene.expression.ld),type="o",lwd=3,col="blue",
        ylim=c(min.expression-expression.step,max.expression))
  legend("topright", 
         legend = c("protein", "gene"), 
         lwd=2, col = c("lightblue", "blue"), 
         lty=c(1,1))
  polygon(x = c(1,5,5,1),y=c(-0.01,
                             -0.01,
                             -0.04,
                             -0.04),lwd=2,border="blue")
  
  polygon(x = c(5,7,7,5),y=c(-0.01,
                             -0.01,
                             -0.04,
                             -0.04),lwd=2,border="blue",col="blue")
  
  polygon(x = c(7,11,11,7),y=c(-0.01,
                               -0.01,
                               -0.04,
                               -0.04),lwd=2,border="blue")
  
  polygon(x = c(11,13,13,11),y=c(-0.01,
                                 -0.01,
                                 -0.04,
                                 -0.04),lwd=2,border="blue",col="blue")
  
  polygon(x = c(13,17,17,13),y=c(-0.01,
                                 -0.01,
                                 -0.04,
                                 -0.04),lwd=2,border="blue")
  
  polygon(x = c(17,19,19,17),y=c(-0.01,
                                 -0.01,
                                 -0.04,
                                 -0.04),lwd=2,border="blue",col="blue")
  
}

plot.ld.ll <- function(gene.id, gene.expression)
{
  ld.zt <- paste("ld",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.ld.ll <- gene.expression[gene.id,c(paste(ld.zt,1,sep="_"),
                                                             paste(ld.zt,2,sep="_"),
                                                             paste(ld.zt,3,sep="_"),
                                                             paste(ld.zt,4,sep="_"),
                                                             paste(ld.zt,5,sep="_"))]
  
  min.expression <- min(current.gene.expression.ld.ll)
  max.expression <- max(current.gene.expression.ld.ll)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld.ll),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=30),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),5),las=2,lwd=3)
  
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(19,23,23,19),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(23,25,25,23),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="lightblue")
  
  polygon(x = c(25,29,29,25),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue")
  polygon(x = c(29,30,30,29),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="lightblue")
  
}

# gene.id<-selected.gene
# gene.expression <- total.gene.expression
plot.ld.dd <- function(gene.id, gene.expression)
{
  ld.zt <- paste("ld",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.ld.dd <- gene.expression[gene.id,c(paste(ld.zt,1,sep="_"),
                                                             paste(ld.zt,2,sep="_"),
                                                             paste(ld.zt,3,sep="_"),
                                                             paste(ld.zt,6,sep="_"),
                                                             paste(ld.zt,7,sep="_"))]
  
  min.expression <- min(current.gene.expression.ld.dd)
  max.expression <- max(current.gene.expression.ld.dd)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld.dd),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=30),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),5),las=2,lwd=3)
  
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/2,
                             min.expression-expression.step/2,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/2,
                               min.expression-expression.step/2,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue")
  
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(19,23,23,19),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="lightblue")
  
  polygon(x = c(23,25,25,23),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
  polygon(x = c(25,29,29,25),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="lightblue")
  polygon(x = c(29,30,30,29),y=c(min.expression-expression.step/2,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="blue",col="blue")
  
}

#### SD and LD plots
#gene.id<-selected.gene
#gene.expression <- total.gene.expression
plot.ld.sd <- function(gene.id, gene.expression)
{
  ld.zt <- paste("ld",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.ld <- gene.expression[gene.id,c(paste(ld.zt,1,sep="_"),
                                                             paste(ld.zt,2,sep="_"),
                                                             paste(ld.zt,3,sep="_"))]
  sd.zt <- paste("sd",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.sd <- gene.expression[gene.id,c(paste(sd.zt,1,sep="_"),
                                                          paste(sd.zt,2,sep="_"),
                                                          paste(sd.zt,3,sep="_"))]
  
  min.expression <- min(current.gene.expression.sd, current.gene.expression.ld)
  max.expression <- max(current.gene.expression.sd, current.gene.expression.ld)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  lines(as.numeric(current.gene.expression.sd),type="o",lwd=3,col="red",
       ylim=c(min.expression-expression.step,max.expression))
  legend("topright", 
         legend = c("LD", "SD"), 
         lwd=2, col = c("blue", "red"), 
         lty=c(1,1))
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  
  
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/4,
                               min.expression-expression.step/4,
                               min.expression-expression.step/2,
                               min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/1.3,
                               min.expression-expression.step/1.3,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
}

plot.ld.sd.prot <- function(gene.id, gene.expression.SD, gene.expression.LD)
{
  current.gene.expression.ld <- gene.expression.LD
  
  current.gene.expression.sd <- gene.expression.SD
  
  min.expression <- min(current.gene.expression.sd, current.gene.expression.ld)
  max.expression <- max(current.gene.expression.sd, current.gene.expression.ld)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="Abundance",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=18),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),3),las=2,lwd=3)
  lines(as.numeric(current.gene.expression.sd),type="o",lwd=3,col="red",
        ylim=c(min.expression-expression.step,max.expression))
  legend("topright", 
         legend = c("LD", "SD"), 
         lwd=2, col = c("blue", "red"), 
         lty=c(1,1))
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  
  
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/4,
                               min.expression-expression.step/4,
                               min.expression-expression.step/2,
                               min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  
  
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/1.3,
                               min.expression-expression.step/1.3,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
}

plot.ld.sd.ll <- function(gene.id, gene.expression)
{
  ld.zt <- paste("ld",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.ld.ll <- gene.expression[gene.id,c(paste(ld.zt,1,sep="_"),
                                                             paste(ld.zt,2,sep="_"),
                                                             paste(ld.zt,3,sep="_"),
                                                             paste(ld.zt,4,sep="_"),
                                                             paste(ld.zt,5,sep="_"))]
  
  sd.zt <- paste("sd",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.sd.ll <- gene.expression[gene.id,c(paste(sd.zt,1,sep="_"),
                                                             paste(sd.zt,2,sep="_"),
                                                             paste(sd.zt,3,sep="_"),
                                                             paste(sd.zt,4,sep="_"),
                                                             paste(sd.zt,5,sep="_"))]
  
  min.expression <- min(current.gene.expression.sd.ll, current.gene.expression.ld.ll)
  max.expression <- max(current.gene.expression.sd.ll, current.gene.expression.ld.ll)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld.ll),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=30),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),5),las=2,lwd=3)
  lines(as.numeric(current.gene.expression.sd.ll),type="o",lwd=3,col="red",
        ylim=c(min.expression-expression.step,max.expression))
  legend("topright", 
         legend = c("LD", "SD"), 
         lwd=2, col = c("blue", "red"), 
         lty=c(1,1))
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/4,
                               min.expression-expression.step/4,
                               min.expression-expression.step/2,
                               min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(19,23,23,19),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(23,25,25,23),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="lightblue")
  polygon(x = c(25,29,29,25),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(29,30,30,29),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="lightblue")
  
  
  
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/1.3,
                               min.expression-expression.step/1.3,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  polygon(x = c(19,21,21,19),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(21,25,25,21),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  polygon(x = c(25,27,27,25),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(27,30,30,27),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  
  
}

plot.ld.sd.dd <- function(gene.id, gene.expression)
{
  ld.zt <- paste("ld",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.ld.dd <- gene.expression[gene.id,c(paste(ld.zt,1,sep="_"),
                                                             paste(ld.zt,2,sep="_"),
                                                             paste(ld.zt,3,sep="_"),
                                                             paste(ld.zt,6,sep="_"),
                                                             paste(ld.zt,7,sep="_"))]
  
  sd.zt <- paste("sd",paste0("zt",sprintf(fmt = "%02d",seq(from=0,to=20,by=4))),sep="_")
  current.gene.expression.sd.dd <- gene.expression[gene.id,c(paste(sd.zt,1,sep="_"),
                                                             paste(sd.zt,2,sep="_"),
                                                             paste(sd.zt,3,sep="_"),
                                                             paste(sd.zt,6,sep="_"),
                                                             paste(sd.zt,7,sep="_"))]
  
  min.expression <- min(current.gene.expression.sd.dd, current.gene.expression.ld.dd)
  max.expression <- max(current.gene.expression.sd.dd, current.gene.expression.ld.dd)
  range.expression <- max.expression - min.expression
  
  expression.step <- floor(range.expression / 5)
  
  plot(as.numeric(current.gene.expression.ld.dd),type="o",lwd=3,col="blue",axes=F,xlab="",ylab="FPKM",
       ylim=c(min.expression-expression.step,max.expression),
       cex.lab=1.3,main=gene.id,cex.main=2)
  axis(side=2,lwd=3)
  axis(side = 1,pos = min.expression - 1.1*expression.step, at = seq(from=1,to=30),
       labels = rep(paste("ZT",seq(from=0,to=20,by=4)),5),las=2,lwd=3)
  lines(as.numeric(current.gene.expression.sd.dd),type="o",lwd=3,col="red",
        ylim=c(min.expression-expression.step,max.expression))
  legend("topright", 
         legend = c("LD", "SD"), 
         lwd=2, col = c("blue", "red"), 
         lty=c(1,1))
  polygon(x = c(1,5,5,1),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(5,7,7,5),y=c(min.expression-expression.step/4,
                             min.expression-expression.step/4,
                             min.expression-expression.step/2,
                             min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(7,11,11,7),y=c(min.expression-expression.step/4,
                               min.expression-expression.step/4,
                               min.expression-expression.step/2,
                               min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(11,13,13,11),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(13,17,17,13),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue")
  polygon(x = c(17,19,19,17),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(19,23,23,19),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="lightblue")
  polygon(x = c(23,25,25,23),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  polygon(x = c(25,29,29,25),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="lightblue")
  polygon(x = c(29,30,30,29),y=c(min.expression-expression.step/4,
                                 min.expression-expression.step/4,
                                 min.expression-expression.step/2,
                                 min.expression-expression.step/2),lwd=2,border="blue",col="blue")
  
  
  
  polygon(x = c(1,3,3,1),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(3,7,7,3),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red",col="red")
  polygon(x = c(7,9,9,7),y=c(min.expression-expression.step/1.3,
                             min.expression-expression.step/1.3,
                             min.expression-expression.step,
                             min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(9,13,13,9),y=c(min.expression-expression.step/1.3,
                               min.expression-expression.step/1.3,
                               min.expression-expression.step,
                               min.expression-expression.step),lwd=2,border="red",col="red")
  polygon(x = c(13,15,15,13),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red")
  polygon(x = c(15,19,19,15),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  polygon(x = c(19,21,21,19),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  polygon(x = c(21,25,25,21),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  polygon(x = c(25,27,27,25),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="salmon")
  polygon(x = c(27,30,30,27),y=c(min.expression-expression.step/1.3,
                                 min.expression-expression.step/1.3,
                                 min.expression-expression.step,
                                 min.expression-expression.step),lwd=2,border="red",col="red")
  
  
}

## Load annotation
ostta.annotation <- read.table(file="ostreococcus_tauri_proteome_annotation.csv",
                               sep="\t",comment.char = "",
                               header=F,
                               as.is=T)[[1]]

# Define UI
ui <- shinyUI(fluidPage(#theme= "bootstrap.css",
    theme = shinytheme("flatly"),
    
    fluidRow(
        column(
            width = 2,
            img(src='logo_minotaur.png', align = "center", width=200),
            tags$br(),
            radioButtons(inputId = "navigation_bar", width="100%",selected="home",
                         label="",
                         choices=c(
                             "Home" = "home",
                             "Individual Gene Exploration" = "individual",
                             "Cluster Functional Analysis" = "clusters",
                             "Tutorials" = "tutorials",
                             "GitHub repository" = "github",
                             "Citation and Contact" = "citation"
                         ))),
        column(
            width = 8,
            tags$div(align = "center", width="100%",
                     tags$h1(tags$b("MINOTAUR"), tags$br()),
                     tags$h2(tags$b("Multi-omics INtegration in", tags$i("Ostreococcus TAURi")))),
            tags$br(),tags$br(),
            conditionalPanel(condition = "input.navigation_bar == 'home'",
                             tags$div(align = "justify", tags$b("Welcome to MINOTAUR!!"), "Although doing research in ", tags$b( "microalgae"), 
                                      "is amazing, we have noticed a lack of easy-to-use tools to analyse and explore omic data. This 
                                      is restricting progress in the microalgae research community. Following Open Science philosophy, 
                                      we have developed different online tools to analyse omic data in microalgae such as", 
                                      tags$a(href="https://greennetwork.us.es/AlgaeFUN/",target="blank",tags$b("AlgaeFUN with MARACAS")), 
                                      "and to explore the omic data generated in our lab such as the current tool", tags$b("MINOTAUR.")),
                             tags$div(align = "justify","Computational analysis for omic data can have a steep learning curve. Therefore 
                             making only raw data available is not enough to ensure accesibility to our results by other independent researchers.
                             To fill this need we have developed ", tags$b("MINOTAUR (Multiomics Integration in Ostreococcus tauri)"), ", 
                             an online app for the exploration of the results of our RNA-seq transcriptomic and SWATH proteomic data generated under
                                      diurnal and seasonal cycles including constant light and constant dark as free running conditions."),
                             tags$div(align="justify", "Please select from the navigation bar on the left the type of analysis you want to perform. 
                                      You can also see our ", tags$b("video tutorial"),". Our code is freely available at", 
                                      tags$a(href="https://github.com/ABRomeroLosada/MINOTAUR", target="blank",tags$b("Github.")), 
                                      "Please cite our work if you find it useful in your research."),
                             tags$div(align="justify", "Below you can find examples of the different graphs that can be generated with MINOTAUR
                                      to explore our results:"), 
                             tags$br(),tags$br(),
                             # 
                             tags$div(align ="center",img(src='ejemplo_intro.png', align = "center", width=800))
            ),
            
            conditionalPanel(condition = "input.navigation_bar == 'clusters'",
                             tags$div(align="justify", tags$b("MINOTAUR"), "allows researchers to perform", tags$b("functional enrichment analysis"), 
                                      "over gene sets.", tags$b("Gene Ontology (GO) enrichment"), "analysis as well as", tags$b("KEGG (Kyoto Encyclopedia
                       of Genes and Genomes) pathway enrichment"), "analysis are supported. MINOTAUR gives access to some of the gene sets 
                       identified in our project, such as rythmic genes sets under specific condtions or sets of genes peaking at a certain time point during the day.", 
                                      " See our", tags$b("video tutorial"),
                                      "for details or follow the next steps to perform your analysis:",
                                      tags$ol(
                                        tags$li("In the left panel below, choose your", tags$b("gene set"), "of interest."),
                                        tags$li("In the right panel below, choose the type of enrichment analysis to perform and your", tags$b("p-value threshold.")),
                                        tags$li("Click on the ", tags$b("Have Fun"), " button to perform the specified functional enrichment analysis. The
                                          results will be shown in the different tabs below.")
                                      )
                             )),
            
            conditionalPanel(condition = "input.navigation_bar == 'individual'",
                             tags$div(align="justify", tags$b("MINOTAUR"), "allows researchers to explore the expression/abundance profiles of 
                                      individual genes/proteins in",tags$b(tags$i("Ostreococcus tauri")), " and analyse their rhythmicity. 
                                      This data has been generated in our lab over three complete diurnal cycles under", 
                                      tags$b("long day (summer day, 16h light / 8h dark) and short day (winter day, 8h light / 16h dark)"), 
                             "conditions. ", tags$b("Free running conditions"), "consisting of two days under ",
                             tags$b("constant light (LL) and constant dark (DD)"), "are
                             also included. In this app, users can visualize gene expression and/or protein abundance profiles of their
                             interest, compare their patterns under short day, long day conditions and free running conditions. Users can also
                             perform" , tags$b("statistical analysis"),  "over the rhythmicity of gene/protein expression/abundance profiles.", " See our", tags$b("video tutorial"),
                                      "for details or follow the next steps to perform your analysis:",
                                      tags$ol(
                                          tags$li("In the left panel below choose your favourite", tags$b("omic data"),"analysis and enter your favourite", 
                                                  tags$b("gene/protein ID.")),
                                          tags$li("In the right panel below choose your", tags$b("photoperiod"), 
                                          "of interest and decide if you want to combine it with some ", tags$b("free running conditions.")),
                                          tags$li("Click on the ", tags$b("Have Fun"), " button to perform the specified analysis. The
                                          results will be shown in the different tabs below.")
                                      )
                             )),
            

            conditionalPanel(condition = "input.navigation_bar == 'github'",
                             tags$div(align = "justify", tags$b("MINOTAUR,"), "is entirely developed using 
        the R package", tags$b( tags$a(href="https://shiny.rstudio.com/", "shiny.")), "The 
        source code is hosted at", tags$b("GitHub."), 
                             tags$div(align="center",tags$h1(tags$b(tags$a(href="https://github.com/ABRomeroLosada/MINOTAUR",
                                                                           "MINOTAUR at GitHub")))),
                              )),
            
            # conditionalPanel(condition = "input.navigation_bar == 'citation'",
            #                  tags$div(align = "justify", "We are strongly committed to", tags$b("open access software"), 
            #                           "and", tags$b("open science."),"Following our philosophy we have deposited our GitHub code 
            #            into", tags$a(href="https://zenodo.org/record/4754516#.YJxLPSaxUws", target="_blank",tags$b("Zenodo")), ", a
            #            general-purpose open-access repository developed under the", 
            #                           tags$a(href="https://www.openaire.eu/", target="_blank", tags$b("European OpenAIRE program.")), "Meanwhile we publish 
            #            our work in a journal if you find", tags$b("AlgaeFUN with MARACAS"), "useful in your research we would be most grateful if you cite 
            #            our GitHub repository with a,", tags$b("DOI"),  "as follows:",
            #                           tags$br(),
            #                           tags$br(),
            #                           tags$div(tags$b("Romero-Losada, A.B., Arvanitidou, C., de los Reyes, P., 
            #                     García-González, M., Romero-Campero, F.J. (2021) AlgaeFUN with MARACAS, microAlgae FUNctional 
            #                     enrichment tool for MicroAlgae RnA-seq and Chip-seq AnalysiS v1.0, Zenodo, doi:10.5381/zenodo.4754516 doi:10.5381/zenodo.4752818"))),
            #                  
            #                  tags$br(),
                            # tags$br(),
                             #tags$div(align="center", img(src='smiley.png', align = "center", width=200,hight=200)),
                            # tags$br()
                             
           # ),
            
            conditionalPanel(condition = "input.navigation_bar == 'tutorials'",
                             tags$div(align="center",uiOutput("video_tutorial")),
                             tags$div(align = "justify", 
                                      tags$br(),
                                      tags$br(),
                                      tags$div(tags$h4(tags$b("Above you can find a video tutorial on how to use the different tools implemented 
                                in MINOTAUR."))))
                             
            ),
            
        ),
        column(
          width = 2,
          img(src='logo_ibvf.jpg', align = "center", width=100),
          img(src='logo_us.png', align = "center", width=100),
          tags$br(),tags$br(),tags$br(),
          img(src='logo_csic.jpg', align = "center", width=100),
          tags$br(),tags$br(),
          tags$div(align="center",width=60,
                   HTML("<script type=\"text/javascript\" src=\"//rf.revolvermaps.com/0/0/8.js?i=5lhjzp7bkry&amp;m=7&amp;c=ff0000&amp;cr1=ffffff&amp;f=arial&amp;l=33\" async=\"async\"></script>"))
        )
    ),
    
    
    tags$br(),tags$br(),
    
    #Interface where the user can choose his/her preferencies, separated by columns
    fluidRow(
        column(width = 2),
        column(width = 4,
               conditionalPanel(condition = "input.navigation_bar == 'clusters'",    
                                #Choose the kind of analysis that you want us to execute 
                                radioButtons(inputId = "gene_sets",
                                             label="Gene sets availables:",
                                             choices=c("Rhythmic genes sets" = "ritmo",
                                                       "Sets of genes peaking at a certain time point of the day" = "peak"
                                                       
                                             ))),
                  #Choose your favourite photoperiod
                 conditionalPanel(condition = "input.navigation_bar == 'clusters' && input.gene_sets == 'peak'",
                                 selectInput(inputId = "season_cluster", label="Choose your favourite photoperiod", 
                                            
                                            choices=c("Long Days (Summer, 16h light / 8h dark)" = "LD", 
                                                      "Short Days (Winter, 8h light / 16h dark)" = "SD")
                                            )),
               #Transcriptome or proteome?
               conditionalPanel(condition = "input.navigation_bar == 'individual' ",    
                                #Choose the kind of analysis that you are interested in
                                radioButtons(inputId = "omics",
                                             label="Are you interested in transcriptomics and/or proteomics?",
                                             choices=c("Transcriptomics rules!" = "rna",
                                                       "Proteomics nerd" = "prot",
                                                       "Multi-omics integration for the win!" = "integration"
                                             ))),
               
               
               #Choose your favourite time of the day
               conditionalPanel(condition = "input.navigation_bar == 'clusters' && input.gene_sets == 'peak'",
                                selectInput(inputId = "zt", label="Choose your favourite time point of the day where ZTN denotes the moment N hours after
                                            dawn or the beginning of the light period", 
                                            
                                            choices=c("Sunrise(ZT0)" = "0", 
                                                      "ZT4" = "4",
                                                      "ZT8" = "8",
                                                      "ZT12" = "12",
                                                      "ZT16" = "16", 
                                                      "ZT20" = "20"
                                                       ))),
               conditionalPanel(condition = "input.navigation_bar == 'clusters' && input.gene_sets == 'ritmo'",
                                selectInput(inputId = "rhythmic_file", label="Choose your favourite rhythmic gene set", 
                                            
                                            choices=c("Rhythmic under long day, constant light and constant dakness conditions" = "LDLLDD", 
                                                      "Rhythmic under short day, constant light and constant dakness conditions" = "SDLLDD",
                                                      "Rhythmic under long day and constant light" = "LDLL",
                                                      "Rhythmic under short day and constant light" = "SDLL",
                                                      "Rhythmic under long day and constant dakness conditions" = "LDDD",
                                                      "Rhythmic under short day and constant dakness conditions" = "SDDD",
                                                      "Genes activated by light and repressed by darkness under long day conditions" ="LDLD",        
                                                      "Genes activated by light and repressed by darkness under short day conditions" ="SDLD",        
                                                      "Genes repressed by light and activated by darkness under long day conditions" ="LDDL",
                                                      "Genes repressed by light and activated by darkness under short day conditions" ="SDDL", 
                                                      "Rhythmic genes with no clear effect by light or darknes under long day condition" ="noclearLD",
                                                      "Rhythmic genes with no clear effect by light or darknes under short day condition" ="noclearSD",
                                                      "No rhythmic genes under long day conditions" = "noLD",
                                                      "No rhythmic genes under short day conditions" = "noSD")
                                                      
                                                      
                                                      
                                                      
                                            )),
               #Choose your favourite gene
               conditionalPanel(condition = "input.navigation_bar == 'individual'",
                                # textInput(inputId= "gene",
                                #           label= "Select your favourite gene/protein",
                                #           value = "ostta07g03440",
                                #           placeholder = "ostta07g03440"),
                                selectizeInput(inputId= "gene",
                                               label= "Select your favourite gene/protein",
                                               selected = "ostta10g00920 Nitrate Reductase, Molybdenum cofactor oxidoreductase, dimerisation",
                                               choices = NULL, #ostta.annotation,
                                               multiple = FALSE))
               ),
        column(width = 4,
               
               #Favourite photoperiod 
               conditionalPanel(condition = "input.navigation_bar == 'individual' && ( input.omics == 'rna' || input.omics == 'prot')",
                                selectInput(inputId = "season", label="Choose your favourite photoperiod", 
                                            
                                            choices=c("Long Days (Summer, 16h light / 8h dark)" = "LD", 
                                                      "Short Days (Winter, 8h light / 16h dark)" = "SD",
                                                      "Both" = "cicle_comparison")
                                )),
               conditionalPanel(condition = "input.navigation_bar == 'individual' && input.omics == 'integration'",
                                selectInput(inputId = "season_integration", label="Choose your favourite photoperiod", 
                                            
                                            choices=c("Long Days (Summer, 16h light / 8h dark)" = "LD", 
                                                      "Short Days (Winter, 8h light / 16h dark)" = "SD")
                                )),
               
               conditionalPanel(condition = "input.navigation_bar == 'individual' && input.omics == 'rna' ",    
                                #Choose the kind of analysis that you are interested in
                                radioButtons(inputId = "continuo",
                                             label="Would you like to combine your favourite photoperiod with 
                                             continuous light or darkness conditions?",
                                             choices=c("Constant Light (LL)" = "LL",
                                                       "Constant Darkness (DD)" = "DD",
                                                       "My favourite photoperiod is enough" = "3days"
                                             ))),
              #choose the analysis to execute
               conditionalPanel(condition = "input.navigation_bar == 'clusters'",    
                                #Choose the kind of analysis that you want us to execute 
                                radioButtons(inputId = "analysis",
                                             label="Choose your desirable analysis",
                                             choices=c("GO terms enrichment" = "go",
                                                       "KEGG pathways enrichment analysis" = "kegg",
                                                       "Both" = "both"
                                             ))),
               
               conditionalPanel(condition= "(input.analysis == 'go' || input.analysis == 'both') &&
                                   input.navigation_bar == 'clusters'",
                                radioButtons(inputId = "ontology",
                                             label="Choose gene ontology:",
                                             choices = c("Biological process" = "BP",
                                                         "Cellular Component" = "CC",
                                                         "Mollecular Function" = "MF"))),
               #Choose a p-value
               conditionalPanel(condition = "input.navigation_bar == 'clusters'",
                                
                                numericInput(inputId = "pvalue", 
                                             label= "Which will be your chosen p-value?", 
                                             value= 0.05)),
                #Button for functional enrichment over the chosen cluster of genes.
                conditionalPanel(condition = "input.navigation_bar == 'clusters'",
                                 actionButton(inputId = "go.button",label = "Have fun!", icon("send") )                       
                                ),
              conditionalPanel(condition = "input.navigation_bar == 'individual'",
                               actionButton(inputId = "circ.button",label = "Have fun!", icon("send") )                       
              )
               )
              ),
              
        
    tags$br(), tags$br(),
    mainPanel(width = 13,
              
              #Main panel containing the results organized in different tabs: GO map, Go terms data table, and 
              #KEGG pathway maps for gene set enrichment analysis
              
              conditionalPanel(condition = "input.navigation_bar == 'clusters'",
                               tabsetPanel(type ="tabs",
                                           tabPanel(tags$b("GO ENRICHMENT"),
                                                    shinyjs::useShinyjs(),
                                                    hidden(div(id='loading.enrichment.go',h3('Please be patient, computing GO enrichment ...'))), 
                                                    hidden(div(id='ready.enrichment.go',h3('Your GO enrichment is ready!'))), 
                                                    htmlOutput(outputId = "gene_sanity_go"),
                                                    htmlOutput(outputId = "wrong_genes_go"),
                                                    tags$br(),
                                                    htmlOutput(outputId = "intro_go"),
                                                    tags$br(),
                                                    tags$br(),
                                                    tabsetPanel(type = "tabs",
                                                                tabPanel(tags$b("GO Enrichment Table"),
                                                                         tags$br(),
                                                                         htmlOutput(outputId = "textGOTable"),
                                                                         tags$br(), tags$br(),
                                                                         dataTableOutput(outputId = "output_go_table"),
                                                                         uiOutput(outputId = "download_ui_for_go_table")#,
                                                                         #htmlOutput(outputId = "revigo")
                                                                ),
                                                                tabPanel(tags$b("GO Map"),
                                                                         tags$br(),
                                                                         htmlOutput(outputId = "go_graph"),
                                                                         tags$br(), tags$br(),
                                                                         div(style= "overflow:scroll; height:500px; text-align: center;", 
                                                                             plotOutput(outputId = "go.plot", inline = T)),
                                                                         tags$br(),
                                                                         tags$br(), tags$br()),
                                                                tabPanel(tags$b("GO Barplot"),
                                                                         tags$br(),
                                                                         htmlOutput(outputId = "barplot_text"),
                                                                         tags$br(),
                                                                         div(style= "text-align: center;",
                                                                             plotOutput(outputId = "bar.plot",inline=TRUE)),
                                                                         tags$br(),
                                                                         tags$br(), tags$br()),
                                                                tabPanel(tags$b("GO Dotplot"),
                                                                         tags$br(),
                                                                         htmlOutput(outputId = "dotplot_text"),
                                                                         tags$br(),
                                                                         div(style= "text-align: center;",
                                                                             plotOutput(outputId = "dot.plot",inline=TRUE)),
                                                                         tags$br(),
                                                                         tags$br(), tags$br()),
                                                                tabPanel(tags$b("GO Concept Map"),
                                                                         tags$br(),
                                                                         htmlOutput(outputId = "cnetplot_text"),
                                                                         tags$br(),
                                                                         div(style= "text-align: center;",
                                                                             plotOutput(outputId = "cnet.plot",inline=TRUE)),
                                                                         tags$br(),
                                                                         tags$br(),tags$br())
                                                    ) # close tabsetPanel for go result
                                           ), # close tabPanel for KEGG ENRICHMENT
                                           tabPanel(tags$b("KEGG PATHWAY ENRICHMENT"),
                                                    shinyjs::useShinyjs(),
                                                    hidden(div(id='loading.enrichment.kegg',h3('Please be patient, computing KEGG pathway enrichment ...'))), 
                                                    hidden(div(id='ready.enrichment.kegg',h3('Your KEGG enrichment is ready!'))), 
                                                    htmlOutput(outputId = "gene_sanity_kegg"),
                                                    htmlOutput(outputId = "wrong_genes_kegg"),
                                                    tags$br(),
                                                    htmlOutput(outputId = "intro_kegg"),
                                                    tags$br(), tags$br(),
                                                    tabsetPanel(type = "tabs",
                                                                tabPanel(tags$b("KEGG Pathway Enrichment Table"), 
                                                                         tags$br(),
                                                                         htmlOutput(outputId = "textKEGGTable"),
                                                                         htmlOutput(outputId = "kegg_pathway_table_text"),
                                                                         tags$br(),
                                                                         dataTableOutput(outputId = "output_pathway_table"),
                                                                         br(), br(), br()),
                                                                tabPanel(tags$b("KEGG Pathway Visualization"),
                                                                         tags$br(), tags$br(),
                                                                         htmlOutput(outputId = "textKEGGImage"),
                                                                         br(), br(),
                                                                         uiOutput(outputId = "kegg_selectize"),
                                                                         div(style= "text-align: center;",
                                                                             imageOutput("kegg_image", inline = T)),
                                                                         tags$br(), tags$br(),
                                                                         br(), br()),
                                                                tabPanel(tags$b("KEGG Module Enrichment Table"),
                                                                         tags$br(), tags$br(),
                                                                         htmlOutput(outputId = "text_module_kegg"),
                                                                         br(), br(),
                                                                         dataTableOutput(outputId = "output_module_table"),
                                                                         tags$br(), tags$br(),
                                                                         tags$br(), tags$br(),
                                                                         uiOutput(outputId = "kegg_module_selectize"),
                                                                         imageOutput("kegg_module_image"),
                                                                         tags$br(), tags$br())
                                                    )
                                                    
                                           )
                               )
              ),
              
              ## Main panel containing the results for graphical representation of expression/amount of protein profiles 
              ##and statistical analysis of their rhythmicity
              
              conditionalPanel(condition = "input.navigation_bar == 'individual'",
                               hidden(div(id='loading.circ',h3('Please be patient, we are working on it ...'))), 
                               hidden(div(id='ready.circ',h3('Here are the results!!'))),
                               htmlOutput(outputId = "no_protein"),
                               tabsetPanel(type = "tabs",
                                           tabPanel(tags$b("Graphical representation"),
                                                    tags$br(),
                                                    div(style= "text-align: center;",
                                                        plotOutput(outputId = "circadian.plot",inline=TRUE))
                                                    ),
                                           tabPanel(tags$b("Statistical analysis"),
                                                    tags$br(), tags$br(),
                                                    dataTableOutput(outputId = "output_statistical_table"),
                                                    uiOutput(outputId = "download_ui_for_statistical_table"),
                                                    tags$br(),
                                                    div(style= "text-align: center;",
                                                        plotOutput(outputId = "circacompare",inline=TRUE)),
                                                    tags$br(), tags$br(),
                                                    br(), br())
                                           )),
              tags$br(),tags$br(),tags$br(),
              tags$br(),tags$br(),tags$br(),
              tags$br(),tags$br(),tags$br(),
              tags$br(),tags$br(),tags$br(),
              tags$br(),tags$br(),tags$br(),
              tags$br(),tags$br(),tags$br(),
              
              img(src='logo_ibvf.jpg', align = "center", width=100), 
              img(src='logo_us.png', align = "center", width=100),
              img(src='logo_csic.jpg', align = "center", width=100),
              tags$br(),tags$br(),tags$br(),
              
              tags$div(align="justify", tags$b("Hey there!")),
              tags$div(align="justify","Hope you are enjoying this app. Any question or suggestion? Please open up an issue in our
                       github repos or email me at arlosada@us.es", 
                       tags$b("Thank you!")),
              tags$br(),tags$br(),tags$br(),
              tags$br(),tags$br(),tags$br(),
              tags$br(),tags$br(),tags$br()
                       
                                                    
)))

server <- shinyServer(function(input, output, session) {
    
    ## video tutorial
    output$video_tutorial <- renderUI({
        HTML("<iframe width=\"560\" height=\"315\" src=\"https://www.youtube.com/embed/ZCWrqOxrdJM\" title=\"YouTube video player\" frameborder=\"0\" allow=\"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture\" allowfullscreen></iframe>")
    })  
  
    ## Server side for target.gene selectize
    updateSelectizeInput(session,inputId =  "gene",
                         selected = "ostta10g00920 Nitrate Reductase, Molybdenum cofactor oxidoreductase, dimerisation",
                         choices = ostta.annotation, 
                         server = TRUE)
    
 
    ## Actions to perform after click the go button
    observeEvent(input$go.button , {
        shinyjs::showElement(id = 'loading.enrichment.go')
        shinyjs::hideElement(id = 'ready.enrichment.go')
        
        # Remove previous results
        output$intro_go <- renderText(expr = "")
        output$gene_sanity_go <- renderText(expr = "")
        output$wrong_genes_go  <- renderText(expr = "")
        output$textGOTable <- renderText(expr = "")
        output$output_go_table <- renderDataTable("")
        output$download_ui_for_go_table<- renderUI(expr = NULL)
        #output$revigo<- renderUI(expr = NULL)
        output$go_graph <- renderText(expr = "")
        output$go.plot <- renderPlot(expr = NULL)
        output$barplot_text <- renderText("")
        output$bar.plot <- renderPlot(expr = NULL)
        output$dotplot_text <- renderText("")
        output$dot.plot <- renderPlot(expr = NULL)
        #output$emapplot_text <- renderText("")
        #output$emap.plot <- renderPlot(expr = NULL)
        output$cnetplot_text <- renderText("")
        output$cnet.plot <- renderPlot(expr = NULL)
        target.genes <- NULL
        target.genes.kegg <- NULL
        
        output$intro_kegg <- renderText(expr = "")
        output$output_pathway_table <- renderDataTable(expr = NULL)
        output$textKEGGImage <- renderText(expr = "")
        output$kegg_selectize <- renderUI(expr = NULL)
        output$kegg_image <- renderImage(expr = NULL,deleteFile = T)
        output$text_module_kegg <- renderText(expr = "")
        output$output_module_table <- renderDataTable(expr = NULL)
        
        # Load libraries
        library(clusterProfiler)
        #library(pathview)
        library(org.Otauri.eg.db)
            
        org.db <- org.Otauri.eg.db
        microalgae.genes <- read.table(file = "otauri_universe.txt",as.is = T, comment.char = "", quote="\"")[[1]]
        gene.link.function <- ostta.gene.link
        
        ## Extract genes from cluster text files
        if (input$gene_sets == "peak")
        {
        file.name <- paste(c("cluster_","peak_",as.character(input$zt), ".txt"), collapse="")
        path <- paste(c("clusters_",input$season_cluster),collapse="")
        complete_path<- paste(c(path,file.name),collapse="/")
        target.genes <- read.table(file=complete_path, header=F,as.is = T, comment.char="")
        #target.genes <- read.table(file="clusters_LD/cluster_peak_12.txt", header=F,as.is = T, comment.char="")
        target.genes <- target.genes$V1
        }else if (input$gene_sets == "ritmo")
        {
          if (input$rhythmic_file == "LDLLDD")
          {
            target.genes <- read.table(file="cluster_rhythmic/LD_LL_DD_rhythmic_genes.tsv",header=T, as.is = T, comment.char = "")
            target.genes <- target.genes$geneID
            #head(target.genes)
            }else if (input$rhythmic_file == "SDLLDD")
            {
              target.genes <- read.table(file="cluster_rhythmic/SD_LL_DD_rhythmic_genes.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$geneID
              }else if (input$rhythmic_file == "LDLL")
            {
              target.genes <- read.table(file="cluster_rhythmic/LD_and_LL_rhythmic_genes.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "SDLL")
            {
              target.genes <- read.table(file="cluster_rhythmic/SD_and_LL_rhythmic_genes.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "LDDD")
            {
              target.genes <- read.table(file="cluster_rhythmic/LD_and_DD_rhythmic_genes.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "SDDD")
            {
              target.genes <- read.table(file="cluster_rhythmic/SD_and_DD_rhythmic_genes.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "LDLD")
            {
              target.genes <- read.table(file="cluster_rhythmic/LD_light_activated_dark_repressed.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "SDLD")
            {
              target.genes <- read.table(file="cluster_rhythmic/SD_light_activated_dark_repressed.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "LDDL")
            {
              target.genes <- read.table(file="cluster_rhythmic/LD_light_repressed_dark_activated.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$X
            }else if (input$rhythmic_file == "SDDL")
            {
              target.genes <- read.table(file="cluster_rhythmic/SD_light_repressed_dark_activated.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "noclearLD")
            {
              target.genes <- read.table(file="cluster_rhythmic/LD_no_clear_effect_light_dark_regulation.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "noclearSD")
            {
              target.genes <- read.table(file="cluster_rhythmic/SD_no_clear_effect_light_dark_regulation.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$x
            }else if (input$rhythmic_file == "noLD")
            {
              target.genes <- read.table(file="cluster_rhythmic/LD_non_rhythmic_genes.tsv",header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$geneID
            }else if (input$rhythmic_file == "noSD")
            {
              target.genes <- read.table(file="cluster_rhythmic/SD_non_rhythmic_genes.tsv", header=T, as.is = T, comment.char = "")
              target.genes <- target.genes$geneID
            }
        }
        
      
        ## GO term enirchment analysis
        if(input$analysis == "kegg")
        {
            output$intro_go <- renderText(expr = "<p style=\"color:blue\"><b> You have chosen only to perform a KEGG enrichment analysis.
                                    Please check the content of the KEGG ENRICHMENT tab.</b></p>")
        } else if((input$analysis == "go" || input$analysis == "both") && (length(target.genes) == 0))
        {
            output$intro_go <- renderText(expr = "<p style=\"color:red\"><b> You forgot to select your favourite time of the day. Please, select one. p</b></p>")
        } else if((input$analysis == "go" || input$analysis == "both") && (length(target.genes) > 0))
        {
            ## Intro text for GO enrichment
            go.intro.text <- paste(c("The tabs below present the results from the <b>GO enrichment analysis</b> 
                                      performed over the genes that peak at (<i>ZT", input$zt,
                                     "</i> ...) from the microalgae <b> <i> Ostreococcus tauri </i> </b>"),collapse="") 
            
            output$intro_go <- renderText(expr = go.intro.text)
            ## Perform GO enrichment
            enrich.go <- enrichGO(gene          = target.genes,
                                  universe      = microalgae.genes,
                                  OrgDb         = org.db,
                                  ont           = input$ontology,
                                  pAdjustMethod = "BH",
                                  pvalueCutoff  = input$pvalue,
                                  qvalueCutoff = 1,
                                  readable      = TRUE,
                                  keyType = "GID")
            enrich.go@result$p.adjust <- enrich.go@result$pvalue 
            
            
            ## Generate ouput table
            enrich.go.result <- as.data.frame(enrich.go@result)
            enrich.go.result <- subset(enrich.go.result, pvalue < input$pvalue)
            
            if(nrow(enrich.go.result) > 0)
            {
                ## GO term Description P-value Q-value Enrichment (SetRatio, BgRatio) Genes
                go.term.enrichments <- compute.enrichments(gene.ratios = enrich.go.result$GeneRatio,
                                                           bg.ratios = enrich.go.result$BgRatio)
                
                go.result.table <- data.frame(enrich.go.result$ID, enrich.go.result$Description,
                                              enrich.go.result$pvalue, enrich.go.result$qvalue,
                                              go.term.enrichments, 
                                              gsub(pattern = "/",replacement = " ",x = enrich.go.result$geneID),
                                              stringsAsFactors = FALSE)
                
                colnames(go.result.table) <- c("GO ID", "Description", "p-value", "q-value",
                                               "Enrichment (Target Ratio; BG Ration)","Genes")
                
                go.result.table.with.links <- go.result.table
                ## Add links to the genes
                genes.in.go.enrichment <- go.result.table$Genes
                
                ## Add link to genes
                for(i in 1:length(genes.in.go.enrichment))
                {
                    go.result.table.with.links$Genes[i] <- paste(sapply(X = strsplit(genes.in.go.enrichment[i],split=" ")[[1]],FUN = gene.link.function),collapse=" ")
                }
                
                ## Add links to GO ids
                go.result.table.with.links[["GO ID"]] <- sapply(X = go.result.table.with.links[["GO ID"]], FUN = go.link)
                
                ## Introductory text for GO enrichment table
                go.table.text <- "The table below summarizes the result of the GO term
enrichment analysis. Each row represents a GO term significantly enriched in the target
gene set with respect to the selected gene universe. The first column represents the GO term
identifier. The second column contains a human readable description. For more details on the 
corresponding GO term, click on the identifier in the first column. The third and fourth 
column presents the p-value and q-value (adjusted p-value or FDR) capturing the level
of significance. The fifth column displays the corresponding enrichment value E (m/n; M/N) where
n is the number of genes with annotation from the target set, N is the number of genes with
annotation from the gene universe, m is the number of genes from the target set annotated with the
corresponding GO term and M is the number of genes from the gene universe annotated with
the GO term associated with the corresponding row. The enrichment is then computed as
E = (m/n) / (M/N). Finally, the last column, contains the genes from the target set
annotated with the GO term represented in the corresponding row."
                output$textGOTable <- renderText(expr = go.table.text)
                
                ## Output table with GO enrichment result
                output$output_go_table <- renderDataTable({
                    go.result.table.with.links #go.result.table
                },escape=FALSE,options =list(pageLength = 5))
                
                ## Generate UI to download go enrichment table and creating a downlodable table
                output$download_ui_for_go_table<- renderUI(
                    tagList(downloadButton(outputId= "downloadGOTable", "Download GO Enrichment Table"),tags$br(),tags$br())
                )
                
                ## Download result
                output$downloadGOTable<- downloadHandler(
                    filename= function() {
                        paste("go_enrichment_table",".tsv", sep="")
                    },
                    content= function(file) {
                        write.table(x = go.result.table,quote = F,sep = "\t",
                                    file=file,row.names=FALSE,col.names=TRUE)
                    })
                
                
            go.graph.text <- "The following acyclic graph represents the GO term enrichment
        in the target gene set. Each node stands for a GO term. The color of each node
        indicates the level of significance from grey, non-significant, to intense red,
        highly significant. An arrow is drawn from GO term A to GO term B when A is a more
        general GO term than B or B is more specific than A. Right click on the image to download it."
                
                output$go_graph <- renderText(expr = go.graph.text)
                
                ## GO plot
                output$go.plot <- renderPlot(
                    width     = 940,
                    height    = 900,
                    res       = 120,
                    expr = {
                     
                        goplot(enrich.go,showCategory = 10)

                    })
                
                output$barplot_text <- renderText("In the following barplot each bar represents a significantly enriched 
        GO term. The length of the bar corresponds to the number of genes in the
        target set annotated with the given GO term. The bar color captures the level
        of significance from blue, less significant, to red, more significant. Right click on the image to download it.")
                
                ## Barplot
                output$bar.plot <- renderPlot(
                    width     = 870,
                    height    = 600,
                    res       = 90,
                    expr = {
                        barplot(enrich.go,drop=TRUE)#,showCategory = 10)
                    })
                
                output$dotplot_text <- renderText("In the following dotplot each dot represents a significantly enriched 
        GO term. The x-position of the dot corresponds to the ratio between the number of genes annotated with the
corresponding GO term and the total number of annotated genes in the target set. The dot color captures the level
        of significance from blue, less significant, to red, more significant. Right click on the image to download it.")
                
                ## Dotplot
                output$dot.plot <- renderPlot(
                    width     = 870,
                    height    = 600,
                    res       = 90,
                    expr = {
                        dotplot(enrich.go)
                    })
              
                output$cnetplot_text <- renderText("The following figure corresponds to a gene-concept network. The beige
nodes represents GO terms and the grey nodes genes. An edge is drawn from a gene to a GO term when the gene is annotated
with the corresponding gene. The size of nodes representing GO terms is proportional to the number of genes annotated
with the corresponding GO term. Right click on the image to download it.")
                
                
                ##CNET plot
                output$cnet.plot <- renderPlot(
                    width     = 870,
                    height    = 600,
                    res       = 90,
                    expr = {
                        cnetplot(enrich.go)
                    })
            } else
            {
                output$textGOTable <- renderText(expr = "<b>No GO term enrichment detected 
                                         in the input gene set.</b>")
                output$go_graph <- renderText(expr = "<b>No GO term enrichment detected 
                                         in the input gene set.</b>")
                output$barplot_text <- renderText(expr = "<b>No GO term enrichment detected 
                                         in the input gene set.</b>")
                output$dotplot_text <- renderText(expr = "<b>No GO term enrichment detected 
                                         in the input gene set.</b>")  
                output$cnetplot_text <- renderText(expr = "<b>No GO term enrichment detected 
                                         in the input gene set.</b>")        
            }
            
            shinyjs::hideElement(id = 'loading.enrichment.go')
            shinyjs::showElement(id = 'ready.enrichment.go')
        }
        
        ## KEGG pathways enrichment analysis
        if(input$analysis == "go")
        {
            output$intro_kegg <- renderText(expr = "<p style=\"color:blue\"><b> You have chosen only to perform a GO enrichment analysis.
                                    Please check the content of the GO ENRICHMENT tab.</b></p>")
        } else if((input$analysis == "kegg" || input$analysis == "both") && (length(target.genes) == 0))
        {
            output$intro_kegg <- renderText(expr = "<p style=\"color:red\"><b> You forgot to select your favourite time of the day. Please, select one. p</b></p>")
        } else if( (input$analysis == "kegg"  || input$analysis == "both") && (length(target.genes) > 0))
        {
            shinyjs::showElement(id = 'loading.enrichment.kegg')
            shinyjs::hideElement(id = 'ready.enrichment.kegg')
            
            ## Update target genes and universe depending on the microalgae
                target.genes.kegg <- paste0("OT_",target.genes)
                gene.universe <- paste0("OT_",microalgae.genes)
                organism.id <- "ota"
            
            ## Compute KEGG pathway enrichment
               pathway.enrichment <- enrichKEGG(gene = target.genes.kegg, organism = organism.id, keyType = "kegg",
                                                 universe = gene.universe,qvalueCutoff = 0.05)#input$pvalue)
            
            shinyjs::showElement(id = 'ready.enrichment.kegg')
            shinyjs::hideElement(id = 'loading.enrichment.kegg')
            
            pathway.enrichment.result <- as.data.frame(pathway.enrichment@result)
            if(nrow(pathway.enrichment.result) > 0)
            {
                kegg.intro.text <- paste(c("The tabs below present the results from the <b>KEGG pathways/modules enrichment analysis</b> 
                                      performed over the genes that peak at (<i>ZT", input$zt,
                                           "</i> ...) from the microalgae <b> <i> Ostreococcus tauri </i> </b>"),collapse="") 
                output$intro_kegg <- renderText(expr = kegg.intro.text)
                
                pathways.enrichment <- compute.enrichments(gene.ratios = pathway.enrichment.result$GeneRatio,
                                                           bg.ratios = pathway.enrichment.result$BgRatio)
                
                ## Generate gene lists for enriched pathways
                 kegg.enriched.genes <- gsub(pattern="OT_",replacement="",x=gsub(pattern = "/",replacement = " ",x = pathway.enrichment.result$geneID))
               
                pathways.result.table <- data.frame(pathway.enrichment.result$ID, pathway.enrichment.result$Description,
                                                    pathway.enrichment.result$pvalue, pathway.enrichment.result$qvalue,
                                                    pathways.enrichment, 
                                                    kegg.enriched.genes,
                                                    stringsAsFactors = FALSE)
                
                colnames(pathways.result.table) <- c("KEGG ID", "Description", "p-value", "q-value",
                                                     "Enrichment (Target Ratio; BG Ration)","Genes")
                
                kegg.result.table.with.links <- pathways.result.table
                
                for(i in 1:length(kegg.enriched.genes))
                {
                    kegg.result.table.with.links$Genes[i] <- paste(sapply(X = strsplit(kegg.enriched.genes[i],split=" ")[[1]],FUN = gene.link.function),collapse=" ")
                }
                
                ## Add links to kegg pathways
                kegg.result.table.with.links[["KEGG ID"]] <- sapply(X=kegg.result.table.with.links[["KEGG ID"]],FUN = kegg.pathway.link)
                
                
                ## Introductory text for GO enrichment table
                kegg.table.text <- "The table below summarizes the result of the KEGG pathway
enrichment analysis. Each row represents a pathway significantly enriched in the target
gene set with respect to the selected gene universe. The first column represents the KEGG pathway 
identifier. The second column contains a human readable description. For more details on the 
corresponding pathway, click on the identifier in the first column. The third and fourth 
column presents the p-value and q-value (adjusted p-value or FDR) capturing the level
of significance. The fifth column displays the corresponding enrichment value E (m/n; M/N) where
n and N are the number of genes associated to any pathway in the target set and in the gene universe
respectively; m and M are the number of genes associated to the pathway represented in the corresponding
row in the target gene set and in the gene universe respectively. The enrichment is then computed as
E = (m/n) / (M/N). Finally, the last column, contains the genes from the target gene set
assocated to the enriched pathway represented in the corresponding row." 
                
                output$textKEGGTable <- renderText(expr = kegg.table.text)
                
                output$output_pathway_table <- renderDataTable({
                    kegg.result.table.with.links
                },escape=FALSE,options =list(pageLength = 5))
                
                
                ## Figures for KEGG pathway enrichment analysis
                
                ## Prepare gene set for representation
                   genes.pathway <- rep(0, length(microalgae.genes))
                   names(genes.pathway) <- microalgae.genes
                    
                  genes.pathway[target.genes.kegg] <- 1
               
                pathways.for.select <- paste(pathways.result.table[["KEGG ID"]], pathways.result.table[["Description"]], sep=" - ")
                
                kegg.image.text <- "<b> The enriched pathways detected above can be visualized using the dropdown menu below. 
      Genes in the target set associated to the corresponding pathway will be highlighted as red rectangles: </b>"
                
                output$textKEGGImage <- renderText(expr = kegg.image.text)
                
                output$kegg_selectize <- renderUI({
                    selectInput(inputId = "kegg_pathway", label="Choose Pathway for Representation",multiple = FALSE,selected = pathways.for.select[1],
                                choices=pathways.for.select)
                })  
            } else
            {
                output$textKEGGTable <- renderText(expr = "<b>No significant KEGG 
                                           pathway enrichment detected in 
                                           the input gene set.")
            }
            
            #KEGG modules enrichment  
            modules.enrichment <- enrichMKEGG(gene = target.genes.kegg, universe = microalgae.genes, organism = organism.id, keyType = "kegg",minGSSize = 4)
            
          
            modules.enrichment.result <- as.data.frame(modules.enrichment)
            if(nrow(modules.enrichment.result) > 0)
            {
                modules.enrichment <- compute.enrichments(gene.ratios = modules.enrichment.result$GeneRatio,
                                                          bg.ratios = modules.enrichment.result$BgRatio)
                modules.enriched.genes <- gsub(pattern="OT_",replacement="",x=gsub(pattern = "/",replacement = " ",x = modules.enrichment.result$geneID))
                
                modules.result.table <- data.frame(modules.enrichment.result$ID, modules.enrichment.result$Description,
                                                   modules.enrichment.result$pvalue, modules.enrichment.result$qvalue,
                                                   modules.enrichment, 
                                                   modules.enriched.genes,
                                                   stringsAsFactors = FALSE)
                
                colnames(modules.result.table) <- c("KEGG ID", "Description", "p-value", "q-value",
                                                    "Enrichment (Target Ratio; BG Ration)","Genes")
                
                modules.result.table.with.links <- modules.result.table
                
                for(i in 1:length(modules.enriched.genes))
                {
                    modules.result.table.with.links$Genes[i] <- paste(sapply(X = strsplit(modules.enriched.genes[i],split=" ")[[1]],FUN = gene.link.function),collapse=" ")
                }
                
                ## Add links to kegg pathways
                modules.result.table.with.links[["KEGG ID"]] <- sapply(X=modules.result.table.with.links[["KEGG ID"]],FUN = kegg.module.link)
                
                
                ## Introductory text for GO enrichment table
                module.table.text <- "The table below summarizes the result of the KEGG module
        enrichment analysis. Modules are sometimes easier to interpret than pathways. Each row represents a module significantly enriched in the target
        gene set with respect to the selected gene universe. The first column represents the KEGG module 
        identifier. The second column contains a human readable description. For more details on the 
        corresponding module, click on the identifier in the first column. The third and fourth 
        column presents the p-value and q-value (adjusted p-value or FDR) capturing the level
        of significance. The fifth column displays the corresponding enrichment value E (m/n; M/N) where
        n and N are the number of genes associated to any module in the target set and in the gene universe
        respectively; m and M are the number of genes associated to the module represented in the corresponding
        row in the target gene set and in the gene universe respectively. The enrichment is then computed as
        E = (m/n) / (M/N). Finally, the last column, contains the genes from the target gene set
        associated to the enriched module represented in the corresponding row." 
                
                output$text_module_kegg <- renderText(expr = module.table.text)
                
                output$output_module_table <- renderDataTable({
                    modules.result.table.with.links
                },escape=FALSE,options =list(pageLength = 5)) 
            } else 
            {
                output$text_module_kegg <- renderText(expr = "<b>No significant KEGG 
                                              module enrichment detected in the 
                                              input gene set.")
            }
         
        
        enriched.pathway.id <- reactive({ 
            if(is.null(input$kegg_pathway))
            {
                return()
            } else
            {
                return(strsplit(input$kegg_pathway,split=" - ")[[1]][1] )
            }
        })
        
        observeEvent(enriched.pathway.id(), {
            
          
             organism.id <- "ota"
             output$kegg_image <- renderImage({
                pathview(gene.data = sort(genes.pathway,decreasing = TRUE),kegg.dir = "pathways",
                         pathway.id = enriched.pathway.id(),
                         species = organism.id,
                         limit = list(gene=max(abs(genes.pathway)), cpd=1),
                         gene.idtype ="kegg")

                list(src = paste(c(enriched.pathway.id(),"pathview","png"), collapse="."),
                     contentType="image/png",width=1200,height=900)
            },deleteFile = T)
        }) 
        }
        
    })
   
    
    observeEvent(input$circ.button, {
  shinyjs::showElement(id = 'loading.circ')
  shinyjs::hideElement(id = 'ready.circ')
  
  #Remove previous results
  #output$intro_go <- renderText(expr = "")
  output$output_statistical_table <- renderDataTable("")
  output$download_ui_for_statistical_table<- renderUI(expr = NULL)
  output$circadian.plot <- renderPlot(expr = NULL)
  output$circacompare <- renderPlot(expr = NULL)
  output$no_protein <- renderText(expr=NULL)
  
  if(input$omics == "rna" )
  {
    #extract gene expression levels of the target gene.
  selected.gene <- strsplit(x = as.character(input$gene),split = " ")[[1]][1]
  #selected.gene <-"ostta01g00060"
  total.gene.expression <- read.table(file = "gene_expression.tsv", header =T)
  gene.expression<- total.gene.expression[selected.gene,]
  
  }else if (input$omics == "prot")
  {
    #Extract protein abundance levels of the corresponding target gene
    #target.prot <- "ostta05g02426"
    target.prot <- strsplit(x = as.character(input$gene),split = " ")[[1]][1]
    #target.prot <-"ostta01g00060"
    swath.normalized.data.SD <- read.table(file = "sd_swath_processed_data.tsv",header=T,sep="\t")
    rownames(swath.normalized.data.SD)<- swath.normalized.data.SD$X
    swath.normalized.data.SD$X <- NULL
    
    swath.normalized.data.LD <- read.table(file = "swath_processed_data.tsv",header=T,sep="\t")
    swath.normalized.data.LD[,"zt20_2"] <- swath.normalized.data.LD[,"zt16_2"]
    swath.normalized.data.LD[,"zt16_2"] <- swath.normalized.data.LD[,"zt20_2"]
    head(swath.normalized.data.SD)
    zts.omics <- c(paste(paste(paste("zt", seq(from=0, to=20, by=4), sep = ""), sep = "_"), 1, sep = "_"),
                   paste(paste(paste("zt", seq(from=0, to=20, by=4), sep = ""), sep = "_"), 2, sep = "_"),
                   paste(paste(paste("zt", seq(from=0, to=20, by=4), sep = ""), sep = "_"), 3, sep = "_"))
    protein.SD <- na.omit(swath.normalized.data.SD[target.prot,])
    protein.SD <- protein.SD[,zts.omics]
    protein.LD <- na.omit(swath.normalized.data.LD[target.prot,])
    protein.LD <- protein.LD[,zts.omics]
    
  } else if (input$omics == "integration")
  {
    #Extract protein abundance levels of the corresponding target gene
    #target.prot <- "ostta07g03440"
    target.prot <- strsplit(x = as.character(input$gene),split = " ")[[1]][1]
    #target.prot <-"ostta01g00060"
    swath.normalized.data.SD <- read.table(file = "sd_swath_processed_data.tsv",header=T,sep="\t")
    rownames(swath.normalized.data.SD)<- swath.normalized.data.SD$X
    swath.normalized.data.SD$X <- NULL
    
    swath.normalized.data.LD <- read.table(file = "swath_processed_data.tsv",header=T,sep="\t")
    swath.normalized.data.LD[,"zt20_2"] <- swath.normalized.data.LD[,"zt16_2"]
    swath.normalized.data.LD[,"zt16_2"] <- swath.normalized.data.LD[,"zt20_2"]
  
    zts.omics <- c(paste(paste(paste("zt", seq(from=0, to=20, by=4), sep = ""), sep = "_"), 1, sep = "_"),
                   paste(paste(paste("zt", seq(from=0, to=20, by=4), sep = ""), sep = "_"), 2, sep = "_"),
                   paste(paste(paste("zt", seq(from=0, to=20, by=4), sep = ""), sep = "_"), 3, sep = "_"))
    protein.SD <- na.omit(swath.normalized.data.SD[target.prot,])
    protein.SD <- protein.SD[,zts.omics]
    protein.LD <- na.omit(swath.normalized.data.LD[target.prot,])
    protein.LD <- protein.LD[,zts.omics]
    
    #extract gene expression levels of the target gene.
    selected.gene <- strsplit(x = as.character(input$gene),split = " ")[[1]][1]
    #selected.gene <-"ostta07g03440"
    total.gene.expression <- read.table(file = "gene_expression.tsv", header =T)
    gene.expression<- total.gene.expression[selected.gene,]
    
  }
  
  if (input$omics == "prot")
  {
    if(input$season == "SD")
    {
      if (nrow(protein.SD) == 0) {
        output$no_protein <- renderText(expr = "<p style=\"color:red\"><b> Sorry, there is no protein detected in our data for the gene selected. p</b></p>")
      }else 
      {
        output$circadian.plot<- renderPlot(
          width     = 870,
          height    = 600,
          res       = 120,
          expr = {
            plot.sd.prot(gene.id=target.prot, 
                    gene.expression=protein.SD)
            
          })
        ###rain analysis
        new.time.points.order <- c(paste("zt0_", seq(from=1, to=3), sep=""),
                                   paste("zt4_", seq(from=1, to=3), sep=""),
                                   paste("zt8_", seq(from=1, to=3), sep=""),
                                   paste("zt12_", seq(from=1, to=3), sep=""),
                                   paste("zt16_", seq(from=1, to=3), sep=""),
                                   paste("zt20_", seq(from=1, to=3), sep=""))
        protein.rain <- protein.SD[,new.time.points.order]
        head(protein.rain)
        
        library(rain)
        rain24.sd<- rain(as.numeric(protein.rain), deltat=4, period=24, verbose=T, nr.series=3)
        rain12.sd<- rain(as.numeric(protein.rain), deltat=4, period=12, verbose=T, nr.series=3)
        
        
        rain.results <- matrix(ncol=3, nrow=1)
        rownames(rain.results) <- c("SD")
        colnames(rain.results) <- c("", "One Peak Rhythmicity", "Two Peaks Rhythmicity")
        rain.results[,1] <-"Rhythmicity under short day (SD) conditions"
        rain.results["SD","One Peak Rhythmicity"] <- rain24.sd$pVal
        rain.results["SD","Two Peaks Rhythmicity"] <- rain12.sd$pVal
        
        output$output_statistical_table <- renderDataTable({
          rain.results 
        },escape=FALSE,options =list(pageLength = 5))
        
        
      }
    }else if (input$season == "LD")
    {
      if (nrow(protein.LD) == 0) {
        output$no_protein <- renderText(expr = "<p style=\"color:red\"><b> Sorry, there is no protein detected in our data for the gene selected. p</b></p>")
      }else 
      {
        output$circadian.plot <- renderPlot(
          width     = 870,
          height    = 600,
          res       = 120,
          expr = {
            plot.ld.prot(gene.id=target.prot, 
                    gene.expression=protein.LD)
          })
        #Prepare data for rain analysis
        new.time.points.order <- c(paste("zt0_", seq(from=1, to=3), sep=""),
                                   paste("zt4_", seq(from=1, to=3), sep=""),
                                   paste("zt8_", seq(from=1, to=3), sep=""),
                                   paste("zt12_", seq(from=1, to=3), sep=""),
                                   paste("zt16_", seq(from=1, to=3), sep=""),
                                   paste("zt20_", seq(from=1, to=3), sep=""))
        protein.rain <- protein.LD[,new.time.points.order]
        head(protein.rain)
      
        library(rain)
        rain24.ld<- rain(as.numeric(protein.rain), deltat=4, period=24, verbose=T, nr.series=3)
        rain12.ld<- rain(as.numeric(protein.rain), deltat=4, period=12, verbose=T, nr.series=3)
        
        rain.results <- matrix(ncol=3, nrow=1)
        rownames(rain.results) <- c("LD")
        colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
        rain.results[,1] <- "Rhythmicity under long day conditions"
        rain.results["LD","One Peak Rhythmicity"] <- rain24.ld$pVal
        rain.results["LD","Two Peaks Rhythmicity"] <- rain12.ld$pVal
        
        output$output_statistical_table <- renderDataTable({
          rain.results 
        },escape=FALSE,options =list(pageLength = 5))
        
      }
    }else if (input$season == "cicle_comparison")
    {
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.ld.sd.prot(gene.id=target.prot,gene.expression.SD = protein.SD, 
                          gene.expression.LD = protein.LD)
          
        })
      #####Circacompare analysis
      library(circacompare)
      time.points <- seq(from=0,by=4,length.out = 18)
      circacompare.SD.LD <- matrix(nrow=15,ncol=2)
      current.gene <- target.prot
      circacomp.data <- data.frame(time=c(time.points,time.points),
                                   measure=c(t(protein.LD/max(protein.LD)),
                                             t(protein.SD/max(protein.SD))),
                                   group=c(rep("Selected protein under LD conditions",18),rep("Selected protein under SD conditions",18)))
      
      result.i<- circacompare(x = circacomp.data, 
                              col_time = "time", 
                              col_group = "group", 
                              col_outcome = "measure",
                              alpha_threshold = 1)
      circacompare.SD.LD[,2] <- result.i[[2]][,2]
      colnames(circacompare.SD.LD) <- c("","")
      rownames(circacompare.SD.LD) <- result.i[[2]][,1]
      circacompare.SD.LD[,1] <- result.i[[2]][,1]
      
      output$output_statistical_table <- renderDataTable({
        circacompare.SD.LD 
      },escape=FALSE,options =list(pageLength = 15))
      
      output$circacompare<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          result.i$plot
        })
      
    }
  }
  
  if(input$omics == "rna")
  {
    if(input$season == "SD" && input$continuo == "3days")
    {
      gene.expression.SD <- gene.expression[,43:60]
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.sd(gene.id=selected.gene, 
                     gene.expression=total.gene.expression)
          
        })
      #Prepare data for rain analysis
      new.time.points.order <- c(paste("sd_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain <- gene.expression.SD[,new.time.points.order]
      head(gene.expression.rain)
      
      
      new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                         paste( "zt4_", seq(from=1, to=3), sep=""),
                         paste( "zt8_", seq(from=1, to=3), sep=""),
                         paste( "zt12_", seq(from=1, to=3), sep=""),
                         paste( "zt16_", seq(from=1, to=3), sep=""),
                         paste( "zt20_", seq(from=1, to=3), sep=""))
      colnames(gene.expression.rain) <- new.rain.order
      library(rain)
      rain24.sd<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.sd<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      
      rain.results <- matrix(ncol=3, nrow=1)
      rownames(rain.results) <- c("SD")
      colnames(rain.results) <- c("", "One Peak Rhythmicity", "Two Peaks Rhythmicity")
      rain.results[,1] <-"Rhythmicity under short day (SD) conditions"
      rain.results["SD","One Peak Rhythmicity"] <- rain24.sd$pVal
      rain.results["SD","Two Peaks Rhythmicity"] <- rain12.sd$pVal
      
      output$output_statistical_table <- renderDataTable({
        rain.results 
      },escape=FALSE,options =list(pageLength = 5))
      
    }else if (input$season == "SD" && input$continuo == "LL")
    {
      gene.expression.SD.LL <- gene.expression[,43:72]
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.sd.ll(gene.id=selected.gene, 
                     gene.expression=total.gene.expression)
          
        })
      #Prepare data for rain analysis
      new.time.points.order <- c(paste("sd_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain <- gene.expression.SD.LL[,new.time.points.order]
      head(gene.expression.rain)
      
      
      new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                         paste( "zt4_", seq(from=1, to=3), sep=""),
                         paste( "zt8_", seq(from=1, to=3), sep=""),
                         paste( "zt12_", seq(from=1, to=3), sep=""),
                         paste( "zt16_", seq(from=1, to=3), sep=""),
                         paste( "zt20_", seq(from=1, to=3), sep=""))
      colnames(gene.expression.rain) <- new.rain.order
      library(rain)
      rain24.sd<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.sd<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      ###rain for LL conditions
      new.time.points.order <- c(paste("sd_", "zt00_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt04_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt08_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt12_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt16_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt20_", seq(from=2, to=5), sep=""))
      gene.expression.rain <- gene.expression.SD.LL[,new.time.points.order]
     
      new.rain.order <-c(paste( "zt0_", seq(from=2, to=5), sep=""),
                         paste( "zt4_", seq(from=2, to=5), sep=""),
                         paste( "zt8_", seq(from=2, to=5), sep=""),
                         paste( "zt12_", seq(from=2, to=5), sep=""),
                         paste( "zt16_", seq(from=2, to=5), sep=""),
                         paste( "zt20_", seq(from=2, to=5), sep=""))
      colnames(gene.expression.rain) <- new.rain.order
      
      library(rain)
      rain24.sd.ll<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.sd.ll<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      rain.results <- matrix(ncol=3, nrow=2)
      rownames(rain.results) <- c("SD", "SD+LL")
      colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
      rain.results[,1] <- c("Rhythmicity under short day (SD) conditions", 
                            "Rhythmicity under constant light conditions (after SD)")
      rain.results["SD","One Peak Rhythmicity"] <- rain24.sd$pVal
      rain.results["SD","Two Peaks Rhythmicity"] <- rain12.sd$pVal
      rain.results["SD+LL","One Peak Rhythmicity"] <- rain24.sd.ll$pVal
      rain.results["SD+LL","Two Peaks Rhythmicity"] <- rain12.sd.ll$pVal
      
      output$output_statistical_table <- renderDataTable({
        rain.results #go.result.table
      },escape=FALSE,options =list(pageLength = 5))
      
    }else if (input$season == "SD" && input$continuo == "DD")
    {
      gene.expression.SD.DD <- c(as.numeric(gene.expression[,43:60]), as.numeric(gene.expression[,73:84]))
      names <-c(names(gene.expression[,43:60]), names(gene.expression[,73:84]))
      names(gene.expression.SD.DD) <- names
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.sd.dd(gene.id=selected.gene, 
                     gene.expression=total.gene.expression)
          
        })
      #Prepare data for rain analysis
      new.time.points.order <- c(paste("sd_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain <- gene.expression.SD.DD[new.time.points.order]
      head(gene.expression.rain)
      
      
      new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                         paste( "zt4_", seq(from=1, to=3), sep=""),
                         paste( "zt8_", seq(from=1, to=3), sep=""),
                         paste( "zt12_", seq(from=1, to=3), sep=""),
                         paste( "zt16_", seq(from=1, to=3), sep=""),
                         paste( "zt20_", seq(from=1, to=3), sep=""))
      names(gene.expression.rain) <- new.rain.order
      library(rain)
      rain24.sd<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.sd<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      ###rain for DD conditions
      new.time.points.order <- c(paste("sd_", "zt00_", seq(from=2, to=3), sep=""),
                                 paste("sd_", "zt00_", seq(from=6, to=7), sep=""),
                                 paste("sd_", "zt04_", seq(from=2, to=3), sep=""),
                                 paste("sd_", "zt04_", seq(from=6, to=7), sep=""),
                                 paste("sd_", "zt08_", seq(from=2, to=3), sep=""),
                                 paste("sd_", "zt08_", seq(from=6, to=7), sep=""),
                                 paste("sd_", "zt12_", seq(from=2, to=3), sep=""),
                                 paste("sd_", "zt12_", seq(from=6, to=7), sep=""),
                                 paste("sd_", "zt16_", seq(from=2, to=3), sep=""),
                                 paste("sd_", "zt16_", seq(from=6, to=7), sep=""),
                                 paste("sd_", "zt20_", seq(from=2, to=3), sep=""),
                                 paste("sd_", "zt20_", seq(from=6, to=7), sep=""))
      gene.expression.rain <- gene.expression.SD.DD[new.time.points.order]
      
      new.rain.order <-c(paste( "zt0_", seq(from=2, to=5), sep=""),
                         paste( "zt4_", seq(from=2, to=5), sep=""),
                         paste( "zt8_", seq(from=2, to=5), sep=""),
                         paste( "zt12_", seq(from=2, to=5), sep=""),
                         paste( "zt16_", seq(from=2, to=5), sep=""),
                         paste( "zt20_", seq(from=2, to=5), sep=""))
      names(gene.expression.rain)<- new.rain.order
      
      library(rain)
      rain24.sd.dd<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.sd.dd<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      rain.results <- matrix(ncol=3, nrow=2)
      rownames(rain.results) <- c("SD", "SD+DD")
      colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
      rain.results[,1] <- c("Rhythmicity under short day (SD) conditions", 
                            "Rhythmicity under constant darkness conditions (after SD)")
      rain.results["SD","One Peak Rhythmicity"] <- rain24.sd$pVal
      rain.results["SD","Two Peaks Rhythmicity"] <- rain12.sd$pVal
      rain.results["SD+DD","One Peak Rhythmicity"] <- rain24.sd.dd$pVal
      rain.results["SD+DD","Two Peaks Rhythmicity"] <- rain12.sd.dd$pVal
      
      output$output_statistical_table <- renderDataTable({
        rain.results #go.result.table
      },escape=FALSE,options =list(pageLength = 5))
      
      
    }else if (input$season == "LD" && input$continuo == "3days")
    { 
      gene.expression.LD <- gene.expression[,1:18]
      output$circadian.plot <- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.ld(gene.id=selected.gene, 
                     gene.expression=total.gene.expression)
        })
      #Prepare data for rain analysis
      new.time.points.order <- c(paste("ld_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain <- gene.expression.LD[,new.time.points.order]
      head(gene.expression.rain)
      
      
      new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                         paste( "zt4_", seq(from=1, to=3), sep=""),
                         paste( "zt8_", seq(from=1, to=3), sep=""),
                         paste( "zt12_", seq(from=1, to=3), sep=""),
                         paste( "zt16_", seq(from=1, to=3), sep=""),
                         paste( "zt20_", seq(from=1, to=3), sep=""))
      colnames(gene.expression.rain) <- new.rain.order
      library(rain)
      rain24.ld<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.ld<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      rain.results <- matrix(ncol=3, nrow=1)
      rownames(rain.results) <- c("LD")
      colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
      rain.results[,1] <- "Rhythmicity under long day conditions"
      rain.results["LD","One Peak Rhythmicity"] <- rain24.ld$pVal
      rain.results["LD","Two Peaks Rhythmicity"] <- rain12.ld$pVal
      
      output$output_statistical_table <- renderDataTable({
        rain.results 
      },escape=FALSE,options =list(pageLength = 5))
      
      
       }else if (input$season== "LD" && input$continuo == "LL")
    {
      gene.expression.LD.LL <- gene.expression[,1:30]
      output$circadian.plot <- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.ld.ll(gene.id=selected.gene, 
                     gene.expression=total.gene.expression)
        })
      #Prepare data for rain analysis
      new.time.points.order <- c(paste("ld_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain <- gene.expression.LD.LL[,new.time.points.order]
      head(gene.expression.rain)
      
      
      new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                         paste( "zt4_", seq(from=1, to=3), sep=""),
                         paste( "zt8_", seq(from=1, to=3), sep=""),
                         paste( "zt12_", seq(from=1, to=3), sep=""),
                         paste( "zt16_", seq(from=1, to=3), sep=""),
                         paste( "zt20_", seq(from=1, to=3), sep=""))
      colnames(gene.expression.rain) <- new.rain.order
      library(rain)
      rain24.ld<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.ld<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      ###rain for DD conditions
      new.time.points.order <- c(paste("ld_", "zt00_", seq(from=2, to=5), sep=""),
                                 paste("ld_", "zt04_", seq(from=2, to=5), sep=""),
                                 paste("ld_", "zt08_", seq(from=2, to=5), sep=""),
                                 paste("ld_", "zt12_", seq(from=2, to=5), sep=""),
                                 paste("ld_", "zt16_", seq(from=2, to=5), sep=""),
                                 paste("ld_", "zt20_", seq(from=2, to=5), sep=""))
      gene.expression.rain <- gene.expression.LD.LL[,new.time.points.order]
      
      new.rain.order <-c(paste( "zt0_", seq(from=2, to=5), sep=""),
                         paste( "zt4_", seq(from=2, to=5), sep=""),
                         paste( "zt8_", seq(from=2, to=5), sep=""),
                         paste( "zt12_", seq(from=2, to=5), sep=""),
                         paste( "zt16_", seq(from=2, to=5), sep=""),
                         paste( "zt20_", seq(from=2, to=5), sep=""))
      colnames(gene.expression.rain) <- new.rain.order
      
      library(rain)
      rain24.ld.ll<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.ld.ll<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      rain.results <- matrix(ncol=3, nrow=2)
      rownames(rain.results) <- c("LD", "LD+LL")
      colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
      rain.results[,1] <- c("Rhythmicity under long day (LD) conditions", 
                            "Rhythmicity under constant light conditions (after LD)")
      rain.results["LD","One Peak Rhythmicity"] <- rain24.ld$pVal
      rain.results["LD","Two Peaks Rhythmicity"] <- rain12.ld$pVal
      rain.results["LD+LL","One Peak Rhythmicity"] <- rain24.ld.ll$pVal
      rain.results["LD+LL","Two Peaks Rhythmicity"] <- rain12.ld.ll$pVal
      
      output$output_statistical_table <- renderDataTable({
        rain.results 
      },escape=FALSE,options =list(pageLength = 5))
      
          
      
    }else if (input$season== "LD" && input$continuo == "DD")
    {
      
      gene.expression.LD.DD <- c(as.numeric(gene.expression[,1:18]), as.numeric(gene.expression[,31:42]))
      names <-c(names(gene.expression[,1:18]), names(gene.expression[,31:42]))
      names(gene.expression.LD.DD) <- names
      output$circadian.plot <- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.ld.dd(gene.id=selected.gene, 
                     gene.expression=total.gene.expression)
        })
      #Prepare data for rain analysis
      new.time.points.order <- c(paste("ld_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain <- gene.expression.LD.DD[new.time.points.order]
      head(gene.expression.rain)
      
      
      new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                         paste( "zt4_", seq(from=1, to=3), sep=""),
                         paste( "zt8_", seq(from=1, to=3), sep=""),
                         paste( "zt12_", seq(from=1, to=3), sep=""),
                         paste( "zt16_", seq(from=1, to=3), sep=""),
                         paste( "zt20_", seq(from=1, to=3), sep=""))
      names(gene.expression.rain) <- new.rain.order
      library(rain)
      rain24.ld<- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.ld<- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      ###rain for DD conditions
      new.time.points.order <- c(paste("ld_", "zt00_", seq(from=2, to=3), sep=""),
                                 paste("ld_", "zt00_", seq(from=6, to=7), sep=""),
                                 paste("ld_", "zt04_", seq(from=2, to=3), sep=""),
                                 paste("ld_", "zt04_", seq(from=6, to=7), sep=""),
                                 paste("ld_", "zt08_", seq(from=2, to=3), sep=""),
                                 paste("ld_", "zt08_", seq(from=6, to=7), sep=""),
                                 paste("ld_", "zt12_", seq(from=2, to=3), sep=""),
                                 paste("ld_", "zt12_", seq(from=6, to=7), sep=""),
                                 paste("ld_", "zt16_", seq(from=2, to=3), sep=""),
                                 paste("ld_", "zt16_", seq(from=6, to=7), sep=""),
                                 paste("ld_", "zt20_", seq(from=2, to=3), sep=""),
                                 paste("ld_", "zt20_", seq(from=6, to=7), sep=""))
      gene.expression.rain <- gene.expression.LD.DD[new.time.points.order]
      
      new.rain.order <-c(paste( "zt0_", seq(from=2, to=5), sep=""),
                         paste( "zt4_", seq(from=2, to=5), sep=""),
                         paste( "zt8_", seq(from=2, to=5), sep=""),
                         paste( "zt12_", seq(from=2, to=5), sep=""),
                         paste( "zt16_", seq(from=2, to=5), sep=""),
                         paste( "zt20_", seq(from=2, to=5), sep=""))
      names(gene.expression.rain) <- new.rain.order
      
      library(rain)
      rain24.ld.dd <- rain(as.numeric(gene.expression.rain), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.ld.dd <- rain(as.numeric(gene.expression.rain), deltat=4, period=12, verbose=T, nr.series=3)
      
      rain.results <- matrix(ncol=3, nrow=2)
      rownames(rain.results) <- c("LD", "LD+DD")
      colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
      rain.results[,1] <-c("Rhythmicity under long day (LD) conditions",
                           "Rhythmicity under constant darkness conditions (after LD)")
      rain.results["LD","One Peak Rhythmicity"] <- rain24.ld$pVal
      rain.results["LD","Two Peaks Rhythmicity"] <- rain12.ld$pVal
      rain.results["LD+DD","One Peak Rhythmicity"] <- rain24.ld.dd$pVal
      rain.results["LD+DD","Two Peaks Rhythmicity"] <- rain12.ld.dd$pVal
      
      output$output_statistical_table <- renderDataTable({
        rain.results 
      },escape=FALSE,options =list(pageLength = 5))
      
      
    }else if (input$season== "cicle_comparison" && input$continuo == "3days")
    {
      gene.expression.SD <- gene.expression[,43:60]
      gene.expression.LD <- gene.expression[,1:18]
      
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.ld.sd(gene.id=selected.gene,
                     gene.expression=total.gene.expression)

      })
   #####Circacompare analysis
      library(circacompare)
      time.points <- seq(from=0,by=4,length.out = 18)
      circacompare.SD.LD <- matrix(nrow=15,ncol=2)
      current.gene <- selected.gene
      circacomp.data <- data.frame(time=c(time.points,time.points),
                                   measure=c(t(gene.expression.LD/max(gene.expression.LD)),
                                             t(gene.expression.SD/max(gene.expression.SD))),
                                   group=c(rep("Selected gene under LD conditions",18),rep("selected gene under SD conditions",18)))
      
      result.i<- circacompare(x = circacomp.data, 
                              col_time = "time", 
                              col_group = "group", 
                              col_outcome = "measure",
                              alpha_threshold = 1)
      circacompare.SD.LD[,2] <- result.i[[2]][,2]
      colnames(circacompare.SD.LD) <- c("","")
      rownames(circacompare.SD.LD) <- result.i[[2]][,1]
      circacompare.SD.LD[,1] <- result.i[[2]][,1]
      
      output$output_statistical_table <- renderDataTable({
        circacompare.SD.LD 
      },escape=FALSE,options =list(pageLength = 15))
      
      output$circacompare<- renderPlot(
          width     = 870,
          height    = 600,
          res       = 120,
          expr = {
            result.i$plot
        })
      
    }else if (input$season== "cicle_comparison" && input$continuo == "LL")
    { 
      gene.expression.LD.LL <- gene.expression[,1:30]
      gene.expression.SD.LL <- gene.expression[,43:72]
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.ld.sd.ll(gene.id=selected.gene, 
                     gene.expression=total.gene.expression)
          
        })
      #Prepare data for rain analysis
      new.time.points.order.sd <- c(paste("sd_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("sd_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain.sd <- gene.expression.SD.LL[,new.time.points.order.sd]
      head(gene.expression.rain.sd)
      
      new.time.points.order.ld <- c(paste("ld_", "zt00_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt04_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt08_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt12_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt16_", seq(from=1, to=3), sep=""),
                                 paste("ld_", "zt20_", seq(from=1, to=3), sep=""))
      gene.expression.rain.ld <- gene.expression.LD.LL[,new.time.points.order.ld]
      head(gene.expression.rain.ld)
      
      
      new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                         paste( "zt4_", seq(from=1, to=3), sep=""),
                         paste( "zt8_", seq(from=1, to=3), sep=""),
                         paste( "zt12_", seq(from=1, to=3), sep=""),
                         paste( "zt16_", seq(from=1, to=3), sep=""),
                         paste( "zt20_", seq(from=1, to=3), sep=""))
      colnames(gene.expression.rain.sd) <- new.rain.order
      colnames(gene.expression.rain.ld) <- new.rain.order
      
      
      library(rain)
      rain24.sd<- rain(as.numeric(gene.expression.rain.sd), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.sd<- rain(as.numeric(gene.expression.rain.sd), deltat=4, period=12, verbose=T, nr.series=3)
      rain24.ld<- rain(as.numeric(gene.expression.rain.ld), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.ld<- rain(as.numeric(gene.expression.rain.ld), deltat=4, period=12, verbose=T, nr.series=3)
      
      ###rain for LL conditions
      new.time.points.order.sd.ll <- c(paste("sd_", "zt00_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt04_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt08_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt12_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt16_", seq(from=2, to=5), sep=""),
                                 paste("sd_", "zt20_", seq(from=2, to=5), sep=""))
      gene.expression.rain.sd.ll <- gene.expression.SD.LL[,new.time.points.order.sd.ll]
      
      new.time.points.order.ld.ll <- c(paste("ld_", "zt00_", seq(from=2, to=5), sep=""),
                                       paste("ld_", "zt04_", seq(from=2, to=5), sep=""),
                                       paste("ld_", "zt08_", seq(from=2, to=5), sep=""),
                                       paste("ld_", "zt12_", seq(from=2, to=5), sep=""),
                                       paste("ld_", "zt16_", seq(from=2, to=5), sep=""),
                                       paste("ld_", "zt20_", seq(from=2, to=5), sep=""))
      gene.expression.rain.ld.ll <- gene.expression.LD.LL[,new.time.points.order.ld.ll]
      
      new.rain.order.ll <-c(paste( "zt0_", seq(from=2, to=5), sep=""),
                         paste( "zt4_", seq(from=2, to=5), sep=""),
                         paste( "zt8_", seq(from=2, to=5), sep=""),
                         paste( "zt12_", seq(from=2, to=5), sep=""),
                         paste( "zt16_", seq(from=2, to=5), sep=""),
                         paste( "zt20_", seq(from=2, to=5), sep=""))
      colnames(gene.expression.rain.sd.ll) <- new.rain.order.ll
      colnames(gene.expression.rain.ld.ll) <- new.rain.order.ll
      
      
      library(rain)
      rain24.sd.ll<- rain(as.numeric(gene.expression.rain.sd.ll), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.sd.ll<- rain(as.numeric(gene.expression.rain.sd.ll), deltat=4, period=12, verbose=T, nr.series=3)
      rain24.ld.ll<- rain(as.numeric(gene.expression.rain.ld.ll), deltat=4, period=24, verbose=T, nr.series=3)
      rain12.ld.ll<- rain(as.numeric(gene.expression.rain.ld.ll), deltat=4, period=12, verbose=T, nr.series=3)
      
      
      rain.results <- matrix(ncol=3, nrow=4)
      rownames(rain.results) <- c("SD", "SD+LL","LD", "LD+LL")
      colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
      rain.results[,1] <- c("Rhythmicity under short day (SD) conditions", 
                            "Rhythmicity under constant light conditions (after SD)",
                            "Rhythmicity under long day (LD) conditions", 
                            "Rhythmicity under constant light conditions (after LD)")
      rain.results["SD","One Peak Rhythmicity"] <- rain24.sd$pVal
      rain.results["SD","Two Peaks Rhythmicity"] <- rain12.sd$pVal
      rain.results["LD","One Peak Rhythmicity"] <- rain24.ld$pVal
      rain.results["LD","Two Peaks Rhythmicity"] <- rain12.ld$pVal
      rain.results["SD+LL","One Peak Rhythmicity"] <- rain24.sd.ll$pVal
      rain.results["SD+LL","Two Peaks Rhythmicity"] <- rain12.sd.ll$pVal
      rain.results["LD+LL","One Peak Rhythmicity"] <- rain24.ld.ll$pVal
      rain.results["LD+LL","Two Peaks Rhythmicity"] <- rain12.ld.ll$pVal
      
      
      output$output_statistical_table <- renderDataTable({
        rain.results 
        },escape=FALSE,options =list(pageLength = 5))
      
    }else if (input$season== "cicle_comparison" && input$continuo == "DD")
    {
    gene.expression.LD.DD <- c(as.numeric(gene.expression[,1:18]), as.numeric(gene.expression[,31:42]))
    names <-c(names(gene.expression[,1:18]), names(gene.expression[,31:42]))
    names(gene.expression.LD.DD) <- names
    gene.expression.SD.DD <- c(as.numeric(gene.expression[,43:60]), as.numeric(gene.expression[,73:84]))
    names <-c(names(gene.expression[,43:60]), names(gene.expression[,73:84]))
    names(gene.expression.SD.DD) <- names
    
    output$circadian.plot <- renderPlot(
      width     = 870,
      height    = 600,
      res       = 120,
      expr = {
        plot.ld.sd.dd(gene.id=selected.gene, 
                   gene.expression=total.gene.expression)
      })
    
    #Prepare data for rain analysis
    new.time.points.order.sd <- c(paste("sd_", "zt00_", seq(from=1, to=3), sep=""),
                                  paste("sd_", "zt04_", seq(from=1, to=3), sep=""),
                                  paste("sd_", "zt08_", seq(from=1, to=3), sep=""),
                                  paste("sd_", "zt12_", seq(from=1, to=3), sep=""),
                                  paste("sd_", "zt16_", seq(from=1, to=3), sep=""),
                                  paste("sd_", "zt20_", seq(from=1, to=3), sep=""))
    gene.expression.rain.sd <- gene.expression.SD.DD[new.time.points.order.sd]
    head(gene.expression.rain.sd)
    
    new.time.points.order.ld <- c(paste("ld_", "zt00_", seq(from=1, to=3), sep=""),
                                  paste("ld_", "zt04_", seq(from=1, to=3), sep=""),
                                  paste("ld_", "zt08_", seq(from=1, to=3), sep=""),
                                  paste("ld_", "zt12_", seq(from=1, to=3), sep=""),
                                  paste("ld_", "zt16_", seq(from=1, to=3), sep=""),
                                  paste("ld_", "zt20_", seq(from=1, to=3), sep=""))
    gene.expression.rain.ld <- gene.expression.LD.DD[new.time.points.order.ld]
    head(gene.expression.rain.ld)
    
    
    new.rain.order <-c(paste( "zt0_", seq(from=1, to=3), sep=""),
                       paste( "zt4_", seq(from=1, to=3), sep=""),
                       paste( "zt8_", seq(from=1, to=3), sep=""),
                       paste( "zt12_", seq(from=1, to=3), sep=""),
                       paste( "zt16_", seq(from=1, to=3), sep=""),
                       paste( "zt20_", seq(from=1, to=3), sep=""))
    names(gene.expression.rain.sd) <- new.rain.order
    names(gene.expression.rain.ld) <- new.rain.order
    
    
    library(rain)
    rain24.sd<- rain(as.numeric(gene.expression.rain.sd), deltat=4, period=24, verbose=T, nr.series=3)
    rain12.sd<- rain(as.numeric(gene.expression.rain.sd), deltat=4, period=12, verbose=T, nr.series=3)
    rain24.ld<- rain(as.numeric(gene.expression.rain.ld), deltat=4, period=24, verbose=T, nr.series=3)
    rain12.ld<- rain(as.numeric(gene.expression.rain.ld), deltat=4, period=12, verbose=T, nr.series=3)
    
    ###rain for DD
    
    new.time.points.order.ld.dd <- c(paste("ld_", "zt00_", seq(from=2, to=3), sep=""),
                               paste("ld_", "zt00_", seq(from=6, to=7), sep=""),
                               paste("ld_", "zt04_", seq(from=2, to=3), sep=""),
                               paste("ld_", "zt04_", seq(from=6, to=7), sep=""),
                               paste("ld_", "zt08_", seq(from=2, to=3), sep=""),
                               paste("ld_", "zt08_", seq(from=6, to=7), sep=""),
                               paste("ld_", "zt12_", seq(from=2, to=3), sep=""),
                               paste("ld_", "zt12_", seq(from=6, to=7), sep=""),
                               paste("ld_", "zt16_", seq(from=2, to=3), sep=""),
                               paste("ld_", "zt16_", seq(from=6, to=7), sep=""),
                               paste("ld_", "zt20_", seq(from=2, to=3), sep=""),
                               paste("ld_", "zt20_", seq(from=6, to=7), sep=""))
    gene.expression.rain.ld.dd <- gene.expression.LD.DD[new.time.points.order.ld.dd]
    
    new.time.points.order.sd.dd <- c(paste("sd_", "zt00_", seq(from=2, to=3), sep=""),
                                     paste("sd_", "zt00_", seq(from=6, to=7), sep=""),
                                     paste("sd_", "zt04_", seq(from=2, to=3), sep=""),
                                     paste("sd_", "zt04_", seq(from=6, to=7), sep=""),
                                     paste("sd_", "zt08_", seq(from=2, to=3), sep=""),
                                     paste("sd_", "zt08_", seq(from=6, to=7), sep=""),
                                     paste("sd_", "zt12_", seq(from=2, to=3), sep=""),
                                     paste("sd_", "zt12_", seq(from=6, to=7), sep=""),
                                     paste("sd_", "zt16_", seq(from=2, to=3), sep=""),
                                     paste("sd_", "zt16_", seq(from=6, to=7), sep=""),
                                     paste("sd_", "zt20_", seq(from=2, to=3), sep=""),
                                     paste("sd_", "zt20_", seq(from=6, to=7), sep=""))
    gene.expression.rain.sd.dd <- gene.expression.SD.DD[new.time.points.order.sd.dd]
    
    
    new.rain.order.dd <-c(paste( "zt0_", seq(from=2, to=5), sep=""),
                       paste( "zt4_", seq(from=2, to=5), sep=""),
                       paste( "zt8_", seq(from=2, to=5), sep=""),
                       paste( "zt12_", seq(from=2, to=5), sep=""),
                       paste( "zt16_", seq(from=2, to=5), sep=""),
                       paste( "zt20_", seq(from=2, to=5), sep=""))
    names(gene.expression.rain.sd.dd) <- new.rain.order.dd
    names(gene.expression.rain.ld.dd)<- new.rain.order.dd
    
    library(rain)
    rain24.ld.dd <- rain(as.numeric(gene.expression.rain.ld.dd), deltat=4, period=24, verbose=T, nr.series=3)
    rain12.ld.dd <- rain(as.numeric(gene.expression.rain.ld.dd), deltat=4, period=12, verbose=T, nr.series=3)
    rain24.sd.dd<- rain(as.numeric(gene.expression.rain.sd.dd), deltat=4, period=24, verbose=T, nr.series=3)
    rain12.sd.dd<- rain(as.numeric(gene.expression.rain.sd.dd), deltat=4, period=12, verbose=T, nr.series=3)
    
    
    rain.results <- matrix(ncol=3, nrow=4)
    rownames(rain.results) <- c("SD", "SD+DD","LD", "LD+DD")
    colnames(rain.results) <- c("","One Peak Rhythmicity", "Two Peaks Rhythmicity")
    rain.results[,1] <-c("Rhythmicity under short day (SD) conditions", 
                         "Rhythmicity under constant darkness conditions (after SD)",
                         "Rhythmicity under long day (LD) conditions",
                         "Rhythmicity under constant darkness conditions (after LD)")
    rain.results["LD","One Peak Rhythmicity"] <- rain24.ld$pVal
    rain.results["LD","Two Peaks Rhythmicity"] <- rain12.ld$pVal
    rain.results["LD+DD","One Peak Rhythmicity"] <- rain24.ld.dd$pVal
    rain.results["LD+DD","Two Peaks Rhythmicity"] <- rain12.ld.dd$pVal
    rain.results["SD","One Peak Rhythmicity"] <- rain24.sd$pVal
    rain.results["SD","Two Peaks Rhythmicity"] <- rain12.sd$pVal
    rain.results["SD+DD","One Peak Rhythmicity"] <- rain24.sd.dd$pVal
    rain.results["SD+DD","Two Peaks Rhythmicity"] <- rain12.sd.dd$pVal
    
    output$output_statistical_table <- renderDataTable({
      rain.results 
    },escape=FALSE,options =list(pageLength = 5))
    
    }  
  }
  
  if(input$omics == "integration")
  {
    if(input$season_integration == "SD")
    {
      gene.expression.SD <- gene.expression[,43:60]
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.sd.gene.prot(gene.id=target.prot,
                            gene.expression = total.gene.expression,
                            protein.data = protein.SD)
          
        })
      #####Circacompare analysis
      library(circacompare)
      time.points <- seq(from=0,by=4,length.out = 18)
      circacompare.gene.prot <- matrix(nrow=15,ncol=2)
      current.gene <- target.prot
      circacomp.data <- data.frame(time=c(time.points,time.points),
                                   measure=c(t(gene.expression.SD/max(gene.expression.SD)),
                                             t(protein.SD/max(protein.SD))),
                                   group=c(rep("Selected gene under SD conditions",18),rep("Selected protein under SD conditions",18)))
      
      result.i<- circacompare(x = circacomp.data, 
                              col_time = "time", 
                              col_group = "group", 
                              col_outcome = "measure",
                              alpha_threshold = 1)
      circacompare.gene.prot[,2] <- result.i[[2]][,2]
      colnames(circacompare.gene.prot) <- c("","")
      rownames(circacompare.gene.prot) <- result.i[[2]][,1]
      circacompare.gene.prot[,1] <- result.i[[2]][,1]
      
      output$output_statistical_table <- renderDataTable({
        circacompare.gene.prot 
      },escape=FALSE,options =list(pageLength = 15))
      
      output$circacompare<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          result.i$plot
        })
      
    }else if (input$season_integration =="LD")
    {
      gene.expression.LD <- gene.expression[,1:18]
      output$circadian.plot<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          plot.ld.gene.prot(gene.id=target.prot,gene.expression = total.gene.expression,protein.data = protein.LD)
          
        })
      #####Circacompare analysis
      library(circacompare)
      time.points <- seq(from=0,by=4,length.out = 18)
      circacompare.gene.prot <- matrix(nrow=15,ncol=2)
      current.gene <- target.prot
      circacomp.data <- data.frame(time=c(time.points,time.points),
                                   measure=c(t(gene.expression.LD/max(gene.expression.LD)),
                                             t(protein.LD/max(protein.LD))),
                                   group=c(rep("Selected gene under LD conditions",18),rep("Selected protein under LD conditions",18)))
      
      result.i<- circacompare(x = circacomp.data, 
                              col_time = "time", 
                              col_group = "group", 
                              col_outcome = "measure",
                              alpha_threshold = 1)
      circacompare.gene.prot[,2] <- result.i[[2]][,2]
      colnames(circacompare.gene.prot) <- c("","")
      rownames(circacompare.gene.prot) <- result.i[[2]][,1]
      circacompare.gene.prot[,1] <- result.i[[2]][,1]
      
      output$output_statistical_table <- renderDataTable({
        circacompare.gene.prot 
      },escape=FALSE,options =list(pageLength = 15))
      
      output$circacompare<- renderPlot(
        width     = 870,
        height    = 600,
        res       = 120,
        expr = {
          result.i$plot
        })
    }
  }
  
  shinyjs::showElement(id = 'ready.circ')
  shinyjs::hideElement(id = 'loading.circ')
})
     })
    
# Run the application 
shinyApp(ui = ui, server = server)